@@ -1,8 +1,11 @@
-/* $Id: config.h 1881 2007-06-06 03:24:02Z peter $ */
+/* $Id: config.h 1986 2007-09-21 18:38:29Z peter $ */
 
-#define yasm__splitpath(path, tail)	yasm__splitpath_win(path, tail)
-#define yasm__abspath(path)		yasm__abspath_win(path)
-#define yasm__combpath(from, to)	yasm__combpath_win(from, to)
+#define yasm__splitpath(path, tail)     yasm__splitpath_win(path, tail)
+#define yasm__abspath(path)             yasm__abspath_win(path)
+#define yasm__combpath(from, to)        yasm__combpath_win(from, to)
+
+/* Command name to run C preprocessor */
+#define CPP_PROG "gcc -E"
 
 /* */
 /* #undef ENABLE_NLS */
@@ -13,12 +16,20 @@
 /* */
 /* #undef HAVE_CATGETS */
 
+/* Define to 1 if you have the MacOS X function CFLocaleCopyCurrent in the
+   CoreFoundation framework. */
+/* #undef HAVE_CFLOCALECOPYCURRENT */
+
+/* Define to 1 if you have the MacOS X function CFPreferencesCopyAppValue in
+   the CoreFoundation framework. */
+/* #undef HAVE_CFPREFERENCESCOPYAPPVALUE */
+
 /* Define if the GNU dcgettext() function is already present or preinstalled.
    */
 /* #undef HAVE_DCGETTEXT */
 
-/* Define if you don't have `vprintf' but do have `_doprnt'. */
-/* #undef HAVE_DOPRNT */
+/* Define to 1 if you have the <direct.h> header file. */
+/* #undef HAVE_DIRECT_H */
 
 /* Define to 1 if you have the `getcwd' function. */
 #define HAVE_GETCWD 1
@@ -41,21 +52,15 @@
 /* Define to 1 if you have the <libgen.h> header file. */
 /* #undef HAVE_LIBGEN_H */
 
-/* Define if you have the <limits.h> header file. */
-#define HAVE_LIMITS_H 1
-
-/* Define if you have the `memcpy' function. */
-#define HAVE_MEMCPY 1
-
-/* Define if you have the `memmove' function. */
-#define HAVE_MEMMOVE 1
-
 /* Define if you have the <memory.h> header file. */
 #define HAVE_MEMORY_H 1
 
 /* Define if you have the `mergesort function. */
 /* #undef HAVE_MERGESORT */
 
+/* Define to 1 if you have the `popen' function. */
+#define HAVE_POPEN 1
+
 /* Define if you have the <stdint.h> header file. */
 #define HAVE_STDINT_H 1
 
@@ -83,36 +88,27 @@
 /* Define if you have the `strncasecmp' function. */
 #define HAVE_STRNCASECMP 1
 
-/* Define if you have the `strrchr' function. */
-#define HAVE_STRRCHR 1
-
 /* Define if you have the `strsep' function. */
 #define HAVE_STRSEP 1
 
-/* Define if you have the <sys/param.h> header file. */
-#define HAVE_SYS_PARAM_H 1
-
 /* Define if you have the <sys/stat.h> header file. */
 #define HAVE_SYS_STAT_H 1
 
 /* Define if you have the <sys/types.h> header file. */
 #define HAVE_SYS_TYPES_H 1
 
-/* Define if you have <sys/wait.h> that is POSIX.1 compatible. */
-#define HAVE_SYS_WAIT_H 1
-
 /* Define if you have the `toascii' function. */
 #define HAVE_TOASCII 1
 
 /* Define if you have the <unistd.h> header file. */
 #define HAVE_UNISTD_H 1
 
-/* Define if you have the vprintf function. */
-#define HAVE_VPRINTF 1
-
 /* Define to 1 if you have the `vsnprintf' function. */
 /* #undef HAVE_VSNPRINTF */
 
+/* Define to 1 if you have the `_stricmp' function. */
+/* #undef HAVE__STRICMP */
+
 /* Name of package */
 #define PACKAGE "yasm"
 
@@ -120,22 +116,22 @@
 #define PACKAGE_BUGREPORT "bug-yasm@tortall.net"
 
 /* Define to build version of this package. */
-#define PACKAGE_BUILD "1880"
+#define PACKAGE_BUILD "1985"
 
 /* Define to internal version of this package. */
-#define PACKAGE_INTVER "0.6.1"
+#define PACKAGE_INTVER "0.6.2"
 
 /* Define to the full name of this package. */
 #define PACKAGE_NAME "yasm"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "yasm 0.6.1"
+#define PACKAGE_STRING "yasm 0.6.2"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "yasm"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "0.6.1"
+#define PACKAGE_VERSION "0.6.2"
 
 /* Define if the C compiler supports function prototypes. */
 #define PROTOTYPES 1
@@ -159,7 +155,7 @@
 #define STDC_HEADERS 1
 
 /* Version number of package */
-#define VERSION "0.6.1"
+#define VERSION "0.6.2"
 
 /* Define if using the dmalloc debugging malloc package */
 /* #undef WITH_DMALLOC */
