@@ -24,9 +24,8 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
-#define YASM_LIB_INTERNAL
 #include "util.h"
-/*@unused@*/ RCSID("$Id: bc-incbin.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: bc-incbin.c 1974 2007-09-21 16:37:01Z peter $");
 
 #include "libyasm-stdint.h"
 #include "coretype.h"
@@ -42,12 +41,10 @@
 
 #include "file.h"
 
-#include "bc-int.h"
-
 
 typedef struct bytecode_incbin {
-    /*@only@*/ char *filename;		/* file to include data from */
-    const char *from;		/* filename of what contained incbin */
+    /*@only@*/ char *filename;          /* file to include data from */
+    const char *from;           /* filename of what contained incbin */
 
     /* starting offset to read from (NULL=0) */
     /*@only@*/ /*@null@*/ yasm_expr *start;
@@ -60,10 +57,10 @@ static void bc_incbin_destroy(void *contents);
 static void bc_incbin_print(const void *contents, FILE *f, int indent_level);
 static void bc_incbin_finalize(yasm_bytecode *bc, yasm_bytecode *prev_bc);
 static int bc_incbin_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
-			      void *add_span_data);
+                              void *add_span_data);
 static int bc_incbin_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
-			     yasm_output_value_func output_value,
-			     /*@null@*/ yasm_output_reloc_func output_reloc);
+                             yasm_output_value_func output_value,
+                             /*@null@*/ yasm_output_reloc_func output_reloc);
 
 static const yasm_bytecode_callback bc_incbin_callback = {
     bc_incbin_destroy,
@@ -92,17 +89,17 @@ bc_incbin_print(const void *contents, FILE *f, int indent_level)
     const bytecode_incbin *incbin = (const bytecode_incbin *)contents;
     fprintf(f, "%*s_IncBin_\n", indent_level, "");
     fprintf(f, "%*sFilename=`%s'\n", indent_level, "",
-	    incbin->filename);
+            incbin->filename);
     fprintf(f, "%*sStart=", indent_level, "");
     if (!incbin->start)
-	fprintf(f, "nil (0)");
+        fprintf(f, "nil (0)");
     else
-	yasm_expr_print(incbin->start, f);
+        yasm_expr_print(incbin->start, f);
     fprintf(f, "%*sMax Len=", indent_level, "");
     if (!incbin->maxlen)
-	fprintf(f, "nil (unlimited)");
+        fprintf(f, "nil (unlimited)");
     else
-	yasm_expr_print(incbin->maxlen, f);
+        yasm_expr_print(incbin->maxlen, f);
     fprintf(f, "\n");
 }
 
@@ -113,25 +110,25 @@ bc_incbin_finalize(yasm_bytecode *bc, yasm_bytecode *prev_bc)
     yasm_value val;
 
     if (yasm_value_finalize_expr(&val, incbin->start, prev_bc, 0))
-	yasm_error_set(YASM_ERROR_TOO_COMPLEX,
-		       N_("start expression too complex"));
+        yasm_error_set(YASM_ERROR_TOO_COMPLEX,
+                       N_("start expression too complex"));
     else if (val.rel)
-	yasm_error_set(YASM_ERROR_NOT_ABSOLUTE,
-		       N_("start expression not absolute"));
+        yasm_error_set(YASM_ERROR_NOT_ABSOLUTE,
+                       N_("start expression not absolute"));
     incbin->start = val.abs;
 
     if (yasm_value_finalize_expr(&val, incbin->maxlen, prev_bc, 0))
-	yasm_error_set(YASM_ERROR_TOO_COMPLEX,
-		       N_("maximum length expression too complex"));
+        yasm_error_set(YASM_ERROR_TOO_COMPLEX,
+                       N_("maximum length expression too complex"));
     else if (val.rel)
-	yasm_error_set(YASM_ERROR_NOT_ABSOLUTE,
-		       N_("maximum length expression not absolute"));
+        yasm_error_set(YASM_ERROR_NOT_ABSOLUTE,
+                       N_("maximum length expression not absolute"));
     incbin->maxlen = val.abs;
 }
 
 static int
 bc_incbin_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
-		   void *add_span_data)
+                   void *add_span_data)
 {
     bytecode_incbin *incbin = (bytecode_incbin *)bc->contents;
     FILE *f;
@@ -140,66 +137,66 @@ bc_incbin_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
 
     /* Try to convert start to integer value */
     if (incbin->start) {
-	num = yasm_expr_get_intnum(&incbin->start, 0);
-	if (num)
-	    start = yasm_intnum_get_uint(num);
-	if (!num) {
-	    /* FIXME */
-	    yasm_error_set(YASM_ERROR_NOT_IMPLEMENTED,
-			   N_("incbin does not yet understand non-constant"));
-	    return -1;
-	}
+        num = yasm_expr_get_intnum(&incbin->start, 0);
+        if (num)
+            start = yasm_intnum_get_uint(num);
+        if (!num) {
+            /* FIXME */
+            yasm_error_set(YASM_ERROR_NOT_IMPLEMENTED,
+                           N_("incbin does not yet understand non-constant"));
+            return -1;
+        }
     }
 
     /* Try to convert maxlen to integer value */
     if (incbin->maxlen) {
-	num = yasm_expr_get_intnum(&incbin->maxlen, 0);
-	if (num)
-	    maxlen = yasm_intnum_get_uint(num);
-	if (!num) {
-	    /* FIXME */
-	    yasm_error_set(YASM_ERROR_NOT_IMPLEMENTED,
-			   N_("incbin does not yet understand non-constant"));
-	    return -1;
-	}
+        num = yasm_expr_get_intnum(&incbin->maxlen, 0);
+        if (num)
+            maxlen = yasm_intnum_get_uint(num);
+        if (!num) {
+            /* FIXME */
+            yasm_error_set(YASM_ERROR_NOT_IMPLEMENTED,
+                           N_("incbin does not yet understand non-constant"));
+            return -1;
+        }
     }
 
     /* Open file and determine its length */
     f = yasm_fopen_include(incbin->filename, incbin->from, "rb", NULL);
     if (!f) {
-	yasm_error_set(YASM_ERROR_IO,
-		       N_("`incbin': unable to open file `%s'"),
-		       incbin->filename);
-	return -1;
+        yasm_error_set(YASM_ERROR_IO,
+                       N_("`incbin': unable to open file `%s'"),
+                       incbin->filename);
+        return -1;
     }
     if (fseek(f, 0L, SEEK_END) < 0) {
-	yasm_error_set(YASM_ERROR_IO,
-		       N_("`incbin': unable to seek on file `%s'"),
-		       incbin->filename);
-	return -1;
+        yasm_error_set(YASM_ERROR_IO,
+                       N_("`incbin': unable to seek on file `%s'"),
+                       incbin->filename);
+        return -1;
     }
     flen = (unsigned long)ftell(f);
     fclose(f);
 
     /* Compute length of incbin from start, maxlen, and len */
     if (start > flen) {
-	yasm_warn_set(YASM_WARN_GENERAL,
-		      N_("`incbin': start past end of file `%s'"),
-		      incbin->filename);
-	start = flen;
+        yasm_warn_set(YASM_WARN_GENERAL,
+                      N_("`incbin': start past end of file `%s'"),
+                      incbin->filename);
+        start = flen;
     }
     flen -= start;
     if (incbin->maxlen)
-	if (maxlen < flen)
-	    flen = maxlen;
+        if (maxlen < flen)
+            flen = maxlen;
     bc->len += flen;
     return 0;
 }
 
 static int
 bc_incbin_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
-		  yasm_output_value_func output_value,
-		  /*@unused@*/ yasm_output_reloc_func output_reloc)
+                  yasm_output_value_func output_value,
+                  /*@unused@*/ yasm_output_reloc_func output_reloc)
 {
     bytecode_incbin *incbin = (bytecode_incbin *)bc->contents;
     FILE *f;
@@ -208,37 +205,37 @@ bc_incbin_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
 
     /* Convert start to integer value */
     if (incbin->start) {
-	num = yasm_expr_get_intnum(&incbin->start, 0);
-	if (!num)
-	    yasm_internal_error(
-		N_("could not determine start in bc_tobytes_incbin"));
-	start = yasm_intnum_get_uint(num);
+        num = yasm_expr_get_intnum(&incbin->start, 0);
+        if (!num)
+            yasm_internal_error(
+                N_("could not determine start in bc_tobytes_incbin"));
+        start = yasm_intnum_get_uint(num);
     }
 
     /* Open file */
     f = yasm_fopen_include(incbin->filename, incbin->from, "rb", NULL);
     if (!f) {
-	yasm_error_set(YASM_ERROR_IO, N_("`incbin': unable to open file `%s'"),
-		       incbin->filename);
-	return 1;
+        yasm_error_set(YASM_ERROR_IO, N_("`incbin': unable to open file `%s'"),
+                       incbin->filename);
+        return 1;
     }
 
     /* Seek to start of data */
     if (fseek(f, (long)start, SEEK_SET) < 0) {
-	yasm_error_set(YASM_ERROR_IO,
-		       N_("`incbin': unable to seek on file `%s'"),
-		       incbin->filename);
-	fclose(f);
-	return 1;
+        yasm_error_set(YASM_ERROR_IO,
+                       N_("`incbin': unable to seek on file `%s'"),
+                       incbin->filename);
+        fclose(f);
+        return 1;
     }
 
     /* Read len bytes */
     if (fread(*bufp, 1, (size_t)bc->len, f) < (size_t)bc->len) {
-	yasm_error_set(YASM_ERROR_IO,
-		       N_("`incbin': unable to read %lu bytes from file `%s'"),
-		       bc->len, incbin->filename);
-	fclose(f);
-	return 1;
+        yasm_error_set(YASM_ERROR_IO,
+                       N_("`incbin': unable to read %lu bytes from file `%s'"),
+                       bc->len, incbin->filename);
+        fclose(f);
+        return 1;
     }
 
     *bufp += bc->len;
@@ -248,7 +245,7 @@ bc_incbin_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
 
 yasm_bytecode *
 yasm_bc_create_incbin(char *filename, yasm_expr *start, yasm_expr *maxlen,
-		      yasm_linemap *linemap, unsigned long line)
+                      yasm_linemap *linemap, unsigned long line)
 {
     bytecode_incbin *incbin = yasm_xmalloc(sizeof(bytecode_incbin));
     unsigned long xline;
