@@ -24,15 +24,11 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
-#define YASM_LIB_INTERNAL
 #include "util.h"
-/*@unused@*/ RCSID("$Id: errwarn.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: errwarn.c 1974 2007-09-21 16:37:01Z peter $");
 
 #include <ctype.h>
-
-#ifdef STDC_HEADERS
-# include <stdarg.h>
-#endif
+#include <stdarg.h>
 
 #include "coretype.h"
 
@@ -40,7 +36,7 @@
 #include "errwarn.h"
 
 
-#define MSG_MAXSIZE	1024
+#define MSG_MAXSIZE     1024
 
 /* Default handlers for replacable functions */
 static /*@exits@*/ void def_internal_error_
@@ -113,9 +109,9 @@ yasm_errwarn_initialize(void)
 {
     /* Default enabled warnings.  See errwarn.h for a list. */
     warn_class_enabled = 
-	(1UL<<YASM_WARN_GENERAL) | (1UL<<YASM_WARN_UNREC_CHAR) |
-	(1UL<<YASM_WARN_PREPROC) | (0UL<<YASM_WARN_ORPHAN_LABEL) |
-	(1UL<<YASM_WARN_UNINIT_CONTENTS);
+        (1UL<<YASM_WARN_GENERAL) | (1UL<<YASM_WARN_UNREC_CHAR) |
+        (1UL<<YASM_WARN_PREPROC) | (0UL<<YASM_WARN_ORPHAN_LABEL) |
+        (1UL<<YASM_WARN_UNINIT_CONTENTS);
 
     yasm_eclass = YASM_ERROR_NONE;
     yasm_estr = NULL;
@@ -141,15 +137,15 @@ yasm__conv_unprint(int ch)
     int pos = 0;
 
     if (((ch & ~0x7F) != 0) /*!isascii(ch)*/ && !isprint(ch)) {
-	unprint[pos++] = 'M';
-	unprint[pos++] = '-';
-	ch &= toascii(ch);
+        unprint[pos++] = 'M';
+        unprint[pos++] = '-';
+        ch &= toascii(ch);
     }
     if (iscntrl(ch)) {
-	unprint[pos++] = '^';
-	unprint[pos++] = (ch == '\177') ? '?' : ch | 0100;
+        unprint[pos++] = '^';
+        unprint[pos++] = (ch == '\177') ? '?' : ch | 0100;
     } else
-	unprint[pos++] = ch;
+        unprint[pos++] = ch;
     unprint[pos] = '\0';
 
     return unprint;
@@ -162,8 +158,8 @@ static void
 def_internal_error_(const char *file, unsigned int line, const char *message)
 {
     fprintf(stderr,
-	    yasm_gettext_hook(N_("INTERNAL ERROR at %s, line %u: %s\n")),
-	    file, line, yasm_gettext_hook(message));
+            yasm_gettext_hook(N_("INTERNAL ERROR at %s, line %u: %s\n")),
+            file, line, yasm_gettext_hook(message));
 #ifdef HAVE_ABORT
     abort();
 #else
@@ -189,7 +185,7 @@ def_fatal(const char *fmt, va_list va)
  */
 static errwarn_data *
 errwarn_data_new(yasm_errwarns *errwarns, unsigned long line,
-		 int replace_parser_error)
+                 int replace_parser_error)
 {
     errwarn_data *first, *next, *ins_we, *we;
     enum { INS_NONE, INS_HEAD, INS_AFTER } action = INS_NONE;
@@ -200,42 +196,42 @@ errwarn_data_new(yasm_errwarns *errwarns, unsigned long line,
     ins_we = errwarns->previous_we;
     first = SLIST_FIRST(&errwarns->errwarns);
     if (!ins_we || !first)
-	action = INS_HEAD;
+        action = INS_HEAD;
     while (action == INS_NONE) {
-	next = SLIST_NEXT(ins_we, link);
-	if (line < ins_we->line) {
-	    if (ins_we == first)
-		action = INS_HEAD;
-	    else
-		ins_we = first;
-	} else if (!next)
-	    action = INS_AFTER;
-	else if (line >= ins_we->line && line < next->line)
-	    action = INS_AFTER;
-	else
-	    ins_we = next;
+        next = SLIST_NEXT(ins_we, link);
+        if (line < ins_we->line) {
+            if (ins_we == first)
+                action = INS_HEAD;
+            else
+                ins_we = first;
+        } else if (!next)
+            action = INS_AFTER;
+        else if (line >= ins_we->line && line < next->line)
+            action = INS_AFTER;
+        else
+            ins_we = next;
     }
 
     if (replace_parser_error && ins_we && ins_we->type == WE_PARSERERROR) {
-	/* overwrite last error */	
-	we = ins_we;
+        /* overwrite last error */      
+        we = ins_we;
     } else {
-	/* add a new error */
-	we = yasm_xmalloc(sizeof(errwarn_data));
+        /* add a new error */
+        we = yasm_xmalloc(sizeof(errwarn_data));
 
-	we->type = WE_UNKNOWN;
-	we->line = line;
-	we->xrefline = 0;
-	we->msg = NULL;
-	we->xrefmsg = NULL;
+        we->type = WE_UNKNOWN;
+        we->line = line;
+        we->xrefline = 0;
+        we->msg = NULL;
+        we->xrefmsg = NULL;
 
-	if (action == INS_HEAD)
-	    SLIST_INSERT_HEAD(&errwarns->errwarns, we, link);
-	else if (action == INS_AFTER) {
-	    assert(ins_we != NULL);
-	    SLIST_INSERT_AFTER(ins_we, we, link);
-	} else
-	    yasm_internal_error(N_("Unexpected errwarn insert action"));
+        if (action == INS_HEAD)
+            SLIST_INSERT_HEAD(&errwarns->errwarns, we, link);
+        else if (action == INS_AFTER) {
+            assert(ins_we != NULL);
+            SLIST_INSERT_AFTER(ins_we, we, link);
+        } else
+            yasm_internal_error(N_("Unexpected errwarn insert action"));
     }
 
     /* Remember previous err/warn */
@@ -248,9 +244,9 @@ void
 yasm_error_clear(void)
 {
     if (yasm_estr)
-	yasm_xfree(yasm_estr);
+        yasm_xfree(yasm_estr);
     if (yasm_exrefstr)
-	yasm_xfree(yasm_exrefstr);
+        yasm_xfree(yasm_exrefstr);
     yasm_eclass = YASM_ERROR_NONE;
     yasm_estr = NULL;
     yasm_exrefline = 0;
@@ -261,9 +257,9 @@ int
 yasm_error_matches(yasm_error_class eclass)
 {
     if (yasm_eclass == YASM_ERROR_NONE)
-	return eclass == YASM_ERROR_NONE;
+        return eclass == YASM_ERROR_NONE;
     if (yasm_eclass == YASM_ERROR_GENERAL)
-	return eclass == YASM_ERROR_GENERAL;
+        return eclass == YASM_ERROR_GENERAL;
     return (yasm_eclass & eclass) == eclass;
 }
 
@@ -271,7 +267,7 @@ void
 yasm_error_set_va(yasm_error_class eclass, const char *format, va_list va)
 {
     if (yasm_eclass != YASM_ERROR_NONE)
-	return;
+        return;
 
     yasm_eclass = eclass;
     yasm_estr = yasm_xmalloc(MSG_MAXSIZE+1);
@@ -295,7 +291,7 @@ void
 yasm_error_set_xref_va(unsigned long xrefline, const char *format, va_list va)
 {
     if (yasm_eclass != YASM_ERROR_NONE)
-	return;
+        return;
 
     yasm_exrefline = xrefline;
 
@@ -318,7 +314,7 @@ yasm_error_set_xref(unsigned long xrefline, const char *format, ...)
 
 void
 yasm_error_fetch(yasm_error_class *eclass, char **str, unsigned long *xrefline,
-		 char **xrefstr)
+                 char **xrefstr)
 {
     *eclass = yasm_eclass;
     *str = yasm_estr;
@@ -334,13 +330,13 @@ void yasm_warn_clear(void)
 {
     /* Delete all error/warnings */
     while (!STAILQ_EMPTY(&yasm_warns)) {
-	warn *w = STAILQ_FIRST(&yasm_warns);
+        warn *w = STAILQ_FIRST(&yasm_warns);
 
-	if (w->wstr)
-	    yasm_xfree(w->wstr);
+        if (w->wstr)
+            yasm_xfree(w->wstr);
 
-	STAILQ_REMOVE_HEAD(&yasm_warns, link);
-	yasm_xfree(w);
+        STAILQ_REMOVE_HEAD(&yasm_warns, link);
+        yasm_xfree(w);
     }
 }
 
@@ -348,7 +344,7 @@ yasm_warn_class
 yasm_warn_occurred(void)
 {
     if (STAILQ_EMPTY(&yasm_warns))
-	return YASM_WARN_NONE;
+        return YASM_WARN_NONE;
     return STAILQ_FIRST(&yasm_warns)->wclass;
 }
 
@@ -358,7 +354,7 @@ yasm_warn_set_va(yasm_warn_class wclass, const char *format, va_list va)
     warn *w;
 
     if (!(warn_class_enabled & (1UL<<wclass)))
-	return;	    /* warning is part of disabled class */
+        return;     /* warning is part of disabled class */
 
     w = yasm_xmalloc(sizeof(warn));
     w->wclass = wclass;
@@ -386,9 +382,9 @@ yasm_warn_fetch(yasm_warn_class *wclass, char **str)
     warn *w = STAILQ_FIRST(&yasm_warns);
 
     if (!w) {
-	*wclass = YASM_WARN_NONE;
-	*str = NULL;
-	return;
+        *wclass = YASM_WARN_NONE;
+        *str = NULL;
+        return;
     }
 
     *wclass = w->wclass;
@@ -434,14 +430,14 @@ yasm_errwarns_destroy(yasm_errwarns *errwarns)
 
     /* Delete all error/warnings */
     while (!SLIST_EMPTY(&errwarns->errwarns)) {
-	we = SLIST_FIRST(&errwarns->errwarns);
-	if (we->msg)
-	    yasm_xfree(we->msg);
-	if (we->xrefmsg)
-	    yasm_xfree(we->xrefmsg);
+        we = SLIST_FIRST(&errwarns->errwarns);
+        if (we->msg)
+            yasm_xfree(we->msg);
+        if (we->xrefmsg)
+            yasm_xfree(we->xrefmsg);
 
-	SLIST_REMOVE_HEAD(&errwarns->errwarns, link);
-	yasm_xfree(we);
+        SLIST_REMOVE_HEAD(&errwarns->errwarns, link);
+        yasm_xfree(we);
     }
 
     yasm_xfree(errwarns);
@@ -451,25 +447,25 @@ void
 yasm_errwarn_propagate(yasm_errwarns *errwarns, unsigned long line)
 {
     if (yasm_eclass != YASM_ERROR_NONE) {
-	errwarn_data *we = errwarn_data_new(errwarns, line, 1);
-	yasm_error_class eclass;
+        errwarn_data *we = errwarn_data_new(errwarns, line, 1);
+        yasm_error_class eclass;
 
-	yasm_error_fetch(&eclass, &we->msg, &we->xrefline, &we->xrefmsg);
-	if (eclass != YASM_ERROR_GENERAL
-	    && (eclass & YASM_ERROR_PARSE) == YASM_ERROR_PARSE)
-	    we->type = WE_PARSERERROR;
-	else
-	    we->type = WE_ERROR;
-	errwarns->ecount++;
+        yasm_error_fetch(&eclass, &we->msg, &we->xrefline, &we->xrefmsg);
+        if (eclass != YASM_ERROR_GENERAL
+            && (eclass & YASM_ERROR_PARSE) == YASM_ERROR_PARSE)
+            we->type = WE_PARSERERROR;
+        else
+            we->type = WE_ERROR;
+        errwarns->ecount++;
     }
 
     while (!STAILQ_EMPTY(&yasm_warns)) {
-	errwarn_data *we = errwarn_data_new(errwarns, line, 0);
-	yasm_warn_class wclass;
+        errwarn_data *we = errwarn_data_new(errwarns, line, 0);
+        yasm_warn_class wclass;
 
-	yasm_warn_fetch(&wclass, &we->msg);
-	we->type = WE_WARNING;
-	errwarns->wcount++;
+        yasm_warn_fetch(&wclass, &we->msg);
+        we->type = WE_WARNING;
+        errwarns->wcount++;
     }
 }
 
@@ -477,16 +473,16 @@ unsigned int
 yasm_errwarns_num_errors(yasm_errwarns *errwarns, int warning_as_error)
 {
     if (warning_as_error)
-	return errwarns->ecount+errwarns->wcount;
+        return errwarns->ecount+errwarns->wcount;
     else
-	return errwarns->ecount;
+        return errwarns->ecount;
 }
 
 void
 yasm_errwarns_output_all(yasm_errwarns *errwarns, yasm_linemap *lm,
-			 int warning_as_error,
-			 yasm_print_error_func print_error,
-			 yasm_print_warning_func print_warning)
+                         int warning_as_error,
+                         yasm_print_error_func print_error,
+                         yasm_print_warning_func print_warning)
 {
     errwarn_data *we;
     const char *filename, *xref_filename;
@@ -494,27 +490,27 @@ yasm_errwarns_output_all(yasm_errwarns *errwarns, yasm_linemap *lm,
 
     /* If we're treating warnings as errors, tell the user about it. */
     if (warning_as_error && warning_as_error != 2) {
-	print_error("", 0,
-		    yasm_gettext_hook(N_("warnings being treated as errors")),
-		    NULL, 0, NULL);
-	warning_as_error = 2;
+        print_error("", 0,
+                    yasm_gettext_hook(N_("warnings being treated as errors")),
+                    NULL, 0, NULL);
+        warning_as_error = 2;
     }
 
     /* Output error/warnings. */
     SLIST_FOREACH(we, &errwarns->errwarns, link) {
-	/* Output error/warning */
-	yasm_linemap_lookup(lm, we->line, &filename, &line);
-	if (we->xrefline)
-	    yasm_linemap_lookup(lm, we->xrefline, &xref_filename, &xref_line);
-	else {
-	    xref_filename = NULL;
-	    xref_line = 0;
-	}
-	if (we->type == WE_ERROR || we->type == WE_PARSERERROR)
-	    print_error(filename, line, we->msg, xref_filename, xref_line,
-			we->xrefmsg);
-	else
-	    print_warning(filename, line, we->msg);
+        /* Output error/warning */
+        yasm_linemap_lookup(lm, we->line, &filename, &line);
+        if (we->xrefline)
+            yasm_linemap_lookup(lm, we->xrefline, &xref_filename, &xref_line);
+        else {
+            xref_filename = NULL;
+            xref_line = 0;
+        }
+        if (we->type == WE_ERROR || we->type == WE_PARSERERROR)
+            print_error(filename, line, we->msg, xref_filename, xref_line,
+                        we->xrefmsg);
+        else
+            print_warning(filename, line, we->msg);
     }
 }
 
