@@ -24,9 +24,8 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
-#define YASM_LIB_INTERNAL
 #include "util.h"
-/*@unused@*/ RCSID("$Id: linemap.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: linemap.c 1974 2007-09-21 16:37:01Z peter $");
 
 #include "coretype.h"
 #include "hamt.h"
@@ -35,13 +34,6 @@
 #include "linemap.h"
 
 
-/* Source lines tracking */
-typedef struct {
-    struct line_mapping *vector;
-    unsigned long size;
-    unsigned long allocated;
-} line_mapping_head;
-
 typedef struct line_mapping {
     /* monotonically increasing virtual line */
     unsigned long line;
@@ -71,7 +63,9 @@ struct yasm_linemap {
     unsigned long current;
 
     /* Mappings from virtual to physical line numbers */
-    /*@only@*/ /*@null@*/ line_mapping_head *map;
+    struct line_mapping *map_vector;
+    unsigned long map_size;
+    unsigned long map_allocated;
 
     /* Bytecode and source line information */
     /*@only@*/ line_source_info *source_info;
@@ -86,39 +80,39 @@ filename_delete_one(/*@only@*/ void *d)
 
 void
 yasm_linemap_set(yasm_linemap *linemap, const char *filename,
-		 unsigned long file_line, unsigned long line_inc)
+                 unsigned long file_line, unsigned long line_inc)
 {
     char *copy;
     int replace = 0;
     line_mapping *mapping;
 
     /* Create a new mapping in the map */
-    if (linemap->map->size >= linemap->map->allocated) {
-	/* allocate another size bins when full for 2x space */
-	linemap->map->vector =
-	    yasm_xrealloc(linemap->map->vector, 2*linemap->map->allocated
-			  *sizeof(line_mapping));
-	linemap->map->allocated *= 2;
+    if (linemap->map_size >= linemap->map_allocated) {
+        /* allocate another size bins when full for 2x space */
+        linemap->map_vector =
+            yasm_xrealloc(linemap->map_vector, 2*linemap->map_allocated
+                          *sizeof(line_mapping));
+        linemap->map_allocated *= 2;
     }
-    mapping = &linemap->map->vector[linemap->map->size];
-    linemap->map->size++;
+    mapping = &linemap->map_vector[linemap->map_size];
+    linemap->map_size++;
 
     /* Fill it */
 
     if (!filename) {
-	if (linemap->map->size >= 2)
-	    mapping->filename =
-		linemap->map->vector[linemap->map->size-2].filename;
-	else
-	    filename = "unknown";
+        if (linemap->map_size >= 2)
+            mapping->filename =
+                linemap->map_vector[linemap->map_size-2].filename;
+        else
+            filename = "unknown";
     }
     if (filename) {
-	/* Copy the filename (via shared storage) */
-	copy = yasm__xstrdup(filename);
-	/*@-aliasunique@*/
-	mapping->filename = HAMT_insert(linemap->filenames, copy, copy,
-					&replace, filename_delete_one);
-	/*@=aliasunique@*/
+        /* Copy the filename (via shared storage) */
+        copy = yasm__xstrdup(filename);
+        /*@-aliasunique@*/
+        mapping->filename = HAMT_insert(linemap->filenames, copy, copy,
+                                        &replace, filename_delete_one);
+        /*@=aliasunique@*/
     }
 
     mapping->line = linemap->current;
@@ -128,7 +122,7 @@ yasm_linemap_set(yasm_linemap *linemap, const char *filename,
 
 unsigned long
 yasm_linemap_poke(yasm_linemap *linemap, const char *filename,
-		  unsigned long file_line)
+                  unsigned long file_line)
 {
     unsigned long line;
     line_mapping *mapping;
@@ -136,13 +130,15 @@ yasm_linemap_poke(yasm_linemap *linemap, const char *filename,
     linemap->current++;
     yasm_linemap_set(linemap, filename, file_line, 0);
 
-    mapping = &linemap->map->vector[linemap->map->size-1];
+    mapping = &linemap->map_vector[linemap->map_size-1];
 
     line = linemap->current;
 
     linemap->current++;
-    yasm_linemap_set(linemap, mapping->filename, mapping->file_line,
-		     mapping->line_inc);
+    yasm_linemap_set(linemap, mapping->filename,
+                     mapping->file_line +
+                     mapping->line_inc*(linemap->current-2-mapping->line),
+                     mapping->line_inc);
 
     return line;
 }
@@ -158,18 +154,17 @@ yasm_linemap_create(void)
     linemap->current = 1;
 
     /* initialize mapping vector */
-    linemap->map = yasm_xmalloc(sizeof(line_mapping_head));
-    linemap->map->vector = yasm_xmalloc(8*sizeof(line_mapping));
-    linemap->map->size = 0;
-    linemap->map->allocated = 8;
+    linemap->map_vector = yasm_xmalloc(8*sizeof(line_mapping));
+    linemap->map_size = 0;
+    linemap->map_allocated = 8;
     
     /* initialize source line information array */
     linemap->source_info_size = 2;
     linemap->source_info = yasm_xmalloc(linemap->source_info_size *
-					sizeof(line_source_info));
+                                        sizeof(line_source_info));
     for (i=0; i<linemap->source_info_size; i++) {
-	linemap->source_info[i].bc = NULL;
-	linemap->source_info[i].source = NULL;
+        linemap->source_info[i].bc = NULL;
+        linemap->source_info[i].source = NULL;
     }
 
     return linemap;
@@ -180,18 +175,15 @@ yasm_linemap_destroy(yasm_linemap *linemap)
 {
     size_t i;
     for (i=0; i<linemap->source_info_size; i++) {
-	if (linemap->source_info[i].source)
-	    yasm_xfree(linemap->source_info[i].source);
+        if (linemap->source_info[i].source)
+            yasm_xfree(linemap->source_info[i].source);
     }
     yasm_xfree(linemap->source_info);
 
-    if (linemap->map) {
-	yasm_xfree(linemap->map->vector);
-	yasm_xfree(linemap->map);
-    }
+    yasm_xfree(linemap->map_vector);
 
     if (linemap->filenames)
-	HAMT_destroy(linemap->filenames, filename_delete_one);
+        HAMT_destroy(linemap->filenames, filename_delete_one);
 
     yasm_xfree(linemap);
 }
@@ -204,24 +196,24 @@ yasm_linemap_get_current(yasm_linemap *linemap)
 
 void
 yasm_linemap_add_source(yasm_linemap *linemap, yasm_bytecode *bc,
-			const char *source)
+                        const char *source)
 {
     size_t i;
 
     while (linemap->current > linemap->source_info_size) {
-	/* allocate another size bins when full for 2x space */
-	linemap->source_info = yasm_xrealloc(linemap->source_info,
-	    2*linemap->source_info_size*sizeof(line_source_info));
-	for (i=linemap->source_info_size; i<linemap->source_info_size*2; i++) {
-	    linemap->source_info[i].bc = NULL;
-	    linemap->source_info[i].source = NULL;
-	}
-	linemap->source_info_size *= 2;
+        /* allocate another size bins when full for 2x space */
+        linemap->source_info = yasm_xrealloc(linemap->source_info,
+            2*linemap->source_info_size*sizeof(line_source_info));
+        for (i=linemap->source_info_size; i<linemap->source_info_size*2; i++) {
+            linemap->source_info[i].bc = NULL;
+            linemap->source_info[i].source = NULL;
+        }
+        linemap->source_info_size *= 2;
     }
 
     /* Delete existing info for that line (if any) */
     if (linemap->source_info[linemap->current-1].source)
-	yasm_xfree(linemap->source_info[linemap->current-1].source);
+        yasm_xfree(linemap->source_info[linemap->current-1].source);
 
     linemap->source_info[linemap->current-1].bc = bc;
     linemap->source_info[linemap->current-1].source = yasm__xstrdup(source);
@@ -235,7 +227,7 @@ yasm_linemap_goto_next(yasm_linemap *linemap)
 
 void
 yasm_linemap_lookup(yasm_linemap *linemap, unsigned long line,
-		    const char **filename, unsigned long *file_line)
+                    const char **filename, unsigned long *file_line)
 {
     line_mapping *mapping;
     unsigned long vindex, step;
@@ -243,19 +235,18 @@ yasm_linemap_lookup(yasm_linemap *linemap, unsigned long line,
     assert(line <= linemap->current);
 
     /* Binary search through map to find highest line_index <= index */
-    assert(linemap->map != NULL);
     vindex = 0;
     /* start step as the greatest power of 2 <= size */
     step = 1;
-    while (step*2<=linemap->map->size)
-	step*=2;
+    while (step*2<=linemap->map_size)
+        step*=2;
     while (step>0) {
-	if (vindex+step < linemap->map->size
-		&& linemap->map->vector[vindex+step].line <= line)
-	    vindex += step;
-	step /= 2;
+        if (vindex+step < linemap->map_size
+                && linemap->map_vector[vindex+step].line <= line)
+            vindex += step;
+        step /= 2;
     }
-    mapping = &linemap->map->vector[vindex];
+    mapping = &linemap->map_vector[vindex];
 
     *filename = mapping->filename;
     *file_line = mapping->file_line + mapping->line_inc*(line-mapping->line);
@@ -263,19 +254,19 @@ yasm_linemap_lookup(yasm_linemap *linemap, unsigned long line,
 
 int
 yasm_linemap_traverse_filenames(yasm_linemap *linemap, /*@null@*/ void *d,
-				int (*func) (const char *filename, void *d))
+                                int (*func) (const char *filename, void *d))
 {
     return HAMT_traverse(linemap->filenames, d, (int (*) (void *, void *))func);
 }
 
 int
 yasm_linemap_get_source(yasm_linemap *linemap, unsigned long line,
-			yasm_bytecode **bcp, const char **sourcep)
+                        yasm_bytecode **bcp, const char **sourcep)
 {
     if (line > linemap->source_info_size) {
-	*bcp = NULL;
-	*sourcep = NULL;
-	return 1;
+        *bcp = NULL;
+        *sourcep = NULL;
+        return 1;
     }
 
     *bcp = linemap->source_info[line-1].bc;
