@@ -2,7 +2,7 @@
  * strdup() implementation with error checking (using xmalloc).
  *
  * Copyright (c) 1988, 1993
- *	The Regents of the University of California.  All rights reserved.
+ *      The Regents of the University of California.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -28,14 +28,13 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  */
-#define YASM_LIB_INTERNAL
 #include "util.h"
-RCSID("$Id: xstrdup.c 1855 2007-05-31 06:20:32Z peter $");
+RCSID("$Id: xstrdup.c 1974 2007-09-21 16:37:01Z peter $");
 
 #include "coretype.h"
 
 #if defined(LIBC_SCCS) && !defined(lint)
-static char sccsid[] = "@(#)strdup.c	8.1 (Berkeley) 6/4/93";
+static char sccsid[] = "@(#)strdup.c    8.1 (Berkeley) 6/4/93";
 #endif /* LIBC_SCCS and not lint */
 
 
@@ -46,13 +45,13 @@ static char sccsid[] = "@(#)strdup.c	8.1 (Berkeley) 6/4/93";
 char *
 yasm__xstrdup(const char *str)
 {
-	size_t len;
-	char *copy;
+        size_t len;
+        char *copy;
 
-	len = strlen(str) + 1;
-	copy = yasm_xmalloc(len);
-	memcpy(copy, str, len);
-	return (copy);
+        len = strlen(str) + 1;
+        copy = yasm_xmalloc(len);
+        memcpy(copy, str, len);
+        return (copy);
 }
 
 char *
