@@ -25,22 +25,20 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: dwarf2-info.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: dwarf2-info.c 1974 2007-09-21 16:37:01Z peter $");
 
 /* Need either unistd.h or direct.h (on Windows) to prototype getcwd() */
-#ifdef HAVE_UNISTD_H
+#if defined(HAVE_UNISTD_H)
 #include <unistd.h>
-#elif defined(WIN32) || defined(_WIN32)
+#elif defined(HAVE_DIRECT_H)
 #include <direct.h>
 #endif
 
-#define YASM_LIB_INTERNAL
-#define YASM_BC_INTERNAL
 #include <libyasm.h>
 
 #include "dwarf2-dbgfmt.h"
 
-#define DW_LANG_Mips_Assembler	0x8001
+#define DW_LANG_Mips_Assembler  0x8001
 
 /* Tag encodings */
 typedef enum {
@@ -202,7 +200,7 @@ typedef struct dwarf2_abbrev {
 
 static void dwarf2_abbrev_bc_destroy(void *contents);
 static void dwarf2_abbrev_bc_print(const void *contents, FILE *f,
-				   int indent_level);
+                                   int indent_level);
 static int dwarf2_abbrev_bc_calc_len
     (yasm_bytecode *bc, yasm_bc_add_span_func add_span, void *add_span_data);
 static int dwarf2_abbrev_bc_tobytes
@@ -225,7 +223,7 @@ static const yasm_bytecode_callback dwarf2_abbrev_bc_callback = {
 
 static unsigned long
 dwarf2_add_abbrev_attr(dwarf2_abbrev *abbrev, dwarf_attribute name,
-		       dwarf_form form)
+                       dwarf_form form)
 {
     dwarf2_abbrev_attr *attr = yasm_xmalloc(sizeof(dwarf2_abbrev_attr));
     attr->name = name;
@@ -236,7 +234,7 @@ dwarf2_add_abbrev_attr(dwarf2_abbrev *abbrev, dwarf_attribute name,
 
 static void
 dwarf2_append_expr(yasm_section *sect, /*@only@*/ yasm_expr *expr,
-		   unsigned int size, int leb)
+                   unsigned int size, int leb)
 {
     yasm_datavalhead dvs;
     yasm_bytecode *bc;
@@ -244,9 +242,9 @@ dwarf2_append_expr(yasm_section *sect, /*@only@*/ yasm_expr *expr,
     yasm_dvs_initialize(&dvs);
     yasm_dvs_append(&dvs, yasm_dv_create_expr(expr));
     if (leb == 0)
-	bc = yasm_bc_create_data(&dvs, size, 0, NULL, 0);
+        bc = yasm_bc_create_data(&dvs, size, 0, NULL, 0);
     else
-	bc = yasm_bc_create_leb128(&dvs, leb<0, 0);
+        bc = yasm_bc_create_leb128(&dvs, leb<0, 0);
     yasm_bc_finalize(bc, yasm_dwarf2__append_bc(sect, bc));
     yasm_bc_calc_len(bc, NULL, NULL);
 }
@@ -259,7 +257,7 @@ dwarf2_append_str(yasm_section *sect, const char *str)
 
     yasm_dvs_initialize(&dvs);
     yasm_dvs_append(&dvs, yasm_dv_create_string(yasm__xstrdup(str),
-						strlen(str)));
+                                                strlen(str)));
     bc = yasm_bc_create_data(&dvs, 1, 1, NULL, 0);
     yasm_bc_finalize(bc, yasm_dwarf2__append_bc(sect, bc));
     yasm_bc_calc_len(bc, NULL, NULL);
@@ -267,7 +265,7 @@ dwarf2_append_str(yasm_section *sect, const char *str)
 
 yasm_section *
 yasm_dwarf2__generate_info(yasm_object *object, yasm_section *debug_line,
-			   yasm_section *main_code)
+                           yasm_section *main_code)
 {
     yasm_dbgfmt_dwarf2 *dbgfmt_dwarf2 = (yasm_dbgfmt_dwarf2 *)object->dbgfmt;
     int new;
@@ -276,9 +274,9 @@ yasm_dwarf2__generate_info(yasm_object *object, yasm_section *debug_line,
     dwarf2_head *head;
     char *buf;
     yasm_section *debug_abbrev =
-	yasm_object_get_general(object, ".debug_abbrev", 0, 4, 0, 0, &new, 0);
+        yasm_object_get_general(object, ".debug_abbrev", 0, 4, 0, 0, &new, 0);
     yasm_section *debug_info =
-	yasm_object_get_general(object, ".debug_info", 0, 4, 0, 0, &new, 0);
+        yasm_object_get_general(object, ".debug_info", 0, 4, 0, 0, &new, 0);
 
     yasm_section_set_align(debug_abbrev, 0, 0);
     yasm_section_set_align(debug_info, 0, 0);
@@ -290,7 +288,7 @@ yasm_dwarf2__generate_info(yasm_object *object, yasm_section *debug_line,
     abbrev->tag = DW_TAG_compile_unit;
     abbrev->has_children = 0;
     abc->len = yasm_size_uleb128(abbrev->id) + yasm_size_uleb128(abbrev->tag)
-	+ 3;
+        + 3;
     STAILQ_INIT(&abbrev->attrs);
     yasm_dwarf2__append_bc(debug_abbrev, abc);
 
@@ -303,34 +301,34 @@ yasm_dwarf2__generate_info(yasm_object *object, yasm_section *debug_line,
 
     /* generating info using abbrev 1 */
     dwarf2_append_expr(debug_info,
-	yasm_expr_create_ident(yasm_expr_int(yasm_intnum_create_uint(1)), 0),
-	0, 1);
+        yasm_expr_create_ident(yasm_expr_int(yasm_intnum_create_uint(1)), 0),
+        0, 1);
 
     /* statement list (line numbers) */
     abc->len += dwarf2_add_abbrev_attr(abbrev, DW_AT_stmt_list, DW_FORM_data4);
     dwarf2_append_expr(debug_info,
-	yasm_expr_create_ident(yasm_expr_sym(
-	    yasm_dwarf2__bc_sym(object->symtab,
-				yasm_section_bcs_first(debug_line))), 0),
-	dbgfmt_dwarf2->sizeof_offset, 0);
+        yasm_expr_create_ident(yasm_expr_sym(
+            yasm_dwarf2__bc_sym(object->symtab,
+                                yasm_section_bcs_first(debug_line))), 0),
+        dbgfmt_dwarf2->sizeof_offset, 0);
 
     if (main_code) {
-	yasm_symrec *first;
-	first = yasm_dwarf2__bc_sym(object->symtab,
-				    yasm_section_bcs_first(main_code));
-	/* All code is contiguous in one section */
-	abc->len += dwarf2_add_abbrev_attr(abbrev, DW_AT_low_pc, DW_FORM_addr);
-	dwarf2_append_expr(debug_info,
-	    yasm_expr_create_ident(yasm_expr_sym(first), 0),
-	    dbgfmt_dwarf2->sizeof_address, 0);
+        yasm_symrec *first;
+        first = yasm_dwarf2__bc_sym(object->symtab,
+                                    yasm_section_bcs_first(main_code));
+        /* All code is contiguous in one section */
+        abc->len += dwarf2_add_abbrev_attr(abbrev, DW_AT_low_pc, DW_FORM_addr);
+        dwarf2_append_expr(debug_info,
+            yasm_expr_create_ident(yasm_expr_sym(first), 0),
+            dbgfmt_dwarf2->sizeof_address, 0);
 
-	abc->len += dwarf2_add_abbrev_attr(abbrev, DW_AT_high_pc, DW_FORM_addr);
-	dwarf2_append_expr(debug_info,
-	    yasm_expr_create(YASM_EXPR_ADD, yasm_expr_sym(first),
-		yasm_expr_int(yasm_calc_bc_dist(
-		    yasm_section_bcs_first(main_code),
-		    yasm_section_bcs_last(main_code))), 0),
-	    dbgfmt_dwarf2->sizeof_address, 0);
+        abc->len += dwarf2_add_abbrev_attr(abbrev, DW_AT_high_pc, DW_FORM_addr);
+        dwarf2_append_expr(debug_info,
+            yasm_expr_create(YASM_EXPR_ADD, yasm_expr_sym(first),
+                yasm_expr_int(yasm_calc_bc_dist(
+                    yasm_section_bcs_first(main_code),
+                    yasm_section_bcs_last(main_code))), 0),
+            dbgfmt_dwarf2->sizeof_address, 0);
     }
 
     /* input filename */
@@ -350,8 +348,8 @@ yasm_dwarf2__generate_info(yasm_object *object, yasm_section *debug_line,
     /* language - no standard code for assembler, use MIPS as a substitute */
     abc->len += dwarf2_add_abbrev_attr(abbrev, DW_AT_language, DW_FORM_data2);
     dwarf2_append_expr(debug_info,
-	yasm_expr_create_ident(yasm_expr_int(
-	    yasm_intnum_create_uint(DW_LANG_Mips_Assembler)), 0), 2, 0);
+        yasm_expr_create_ident(yasm_expr_int(
+            yasm_intnum_create_uint(DW_LANG_Mips_Assembler)), 0), 2, 0);
 
     /* Terminate list of abbreviations */
     abbrev = yasm_xmalloc(sizeof(dwarf2_abbrev));
@@ -378,9 +376,9 @@ dwarf2_abbrev_bc_destroy(void *contents)
     /* Delete attributes */
     n1 = STAILQ_FIRST(&abbrev->attrs);
     while (n1) {
-	n2 = STAILQ_NEXT(n1, link);
-	yasm_xfree(n1);
-	n1 = n2;
+        n2 = STAILQ_NEXT(n1, link);
+        yasm_xfree(n1);
+        n1 = n2;
     }
 
     yasm_xfree(contents);
@@ -394,7 +392,7 @@ dwarf2_abbrev_bc_print(const void *contents, FILE *f, int indent_level)
 
 static int
 dwarf2_abbrev_bc_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
-			  void *add_span_data)
+                          void *add_span_data)
 {
     yasm_internal_error(N_("tried to calc_len a dwarf2 aranges head bytecode"));
     /*@notreached@*/
@@ -403,17 +401,17 @@ dwarf2_abbrev_bc_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
 
 static int
 dwarf2_abbrev_bc_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
-			 yasm_output_value_func output_value,
-			 yasm_output_reloc_func output_reloc)
+                         yasm_output_value_func output_value,
+                         yasm_output_reloc_func output_reloc)
 {
     dwarf2_abbrev *abbrev = (dwarf2_abbrev *)bc->contents;
     unsigned char *buf = *bufp;
     dwarf2_abbrev_attr *attr;
 
     if (abbrev->id == 0) {
-	YASM_WRITE_8(buf, 0);
-	*bufp = buf;
-	return 0;
+        YASM_WRITE_8(buf, 0);
+        *bufp = buf;
+        return 0;
     }
 
     buf += yasm_get_uleb128(abbrev->id, buf);
@@ -421,8 +419,8 @@ dwarf2_abbrev_bc_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
     YASM_WRITE_8(buf, abbrev->has_children);
 
     STAILQ_FOREACH(attr, &abbrev->attrs, link) {
-	buf += yasm_get_uleb128(attr->name, buf);
-	buf += yasm_get_uleb128(attr->form, buf);
+        buf += yasm_get_uleb128(attr->name, buf);
+        buf += yasm_get_uleb128(attr->form, buf);
     }
 
     YASM_WRITE_8(buf, 0);
