@@ -25,75 +25,73 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: stabs-dbgfmt.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: stabs-dbgfmt.c 1974 2007-09-21 16:37:01Z peter $");
 
-#define YASM_LIB_INTERNAL
-#define YASM_BC_INTERNAL
 #include <libyasm.h>
 
 typedef enum {
-    N_UNDF = 0x00,	/* Undefined */
-    N_GSYM = 0x20,	/* Global symbol */
-    N_FNAME = 0x22,	/* Function name (BSD Fortran) */
-    N_FUN = 0x24,	/* Function name or Text segment variable */
-    N_STSYM = 0x26,	/* Data segment file-scope variable */
-    N_LCSYM = 0x28,	/* BSS segment file-scope variable */
-    N_MAIN = 0x2a,	/* Name of main routine */
-    N_ROSYM = 0x2c,	/* Variable in .rodata section */
-    N_PC = 0x30,	/* Global symbol (Pascal) */
-    N_SYMS = 0x32,	/* Number of symbols (Ultrix V4.0) */
-    N_NOMAP = 0x34,	/* No DST map */
-    N_OBJ = 0x38,	/* Object file (Solaris2) */
-    N_OPT = 0x3c,	/* Debugger options (Solaris2) */
-    N_RSYM = 0x40,	/* Register variable */
-    N_M2C = 0x42,	/* Modula-2 compilation unit */
-    N_SLINE = 0x44,	/* Line numbers in .text segment */
-    N_DSLINE = 0x46,	/* Line numbers in .data segment */
-    N_BSLINE = 0x48,	/* Line numbers in .bss segment */
-    N_BROWS = 0x48,	/* Source code .cb file's path */
-    N_DEFD = 0x4a,	/* GNU Modula-2 definition module dependency */
-    N_FLINE = 0x4c,	/* Function start/body/end line numbers (Solaris2) */
-    N_EHDECL = 0x50,	/* GNU C++ exception variable */
-    N_MOD2 = 0x50,	/* Modula2 info for imc (Ultrix V4.0) */
-    N_CATCH = 0x54,	/* GNU C++ catch clause */
-    N_SSYM = 0x60,	/* Structure or union element */
-    N_ENDM = 0x62,	/* Last stab for module (Solaris2) */
-    N_SO = 0x64,	/* Path and name of source files */
-    N_LSYM = 0x80,	/* Stack variable */
-    N_BINCL = 0x84,	/* Beginning of include file */
-    N_SOL = 0x84,	/* Name of include file */
-    N_PSYM = 0xa0,	/* Parameter variable */
-    N_EINCL = 0xa2,	/* End of include file */
-    N_ENTRY = 0xa4,	/* Alternate entry point */
-    N_LBRAC = 0xc0,	/* Beginning of lexical block */
-    N_EXCL = 0xc2,	/* Placeholder for a deleted include file */
-    N_SCOPE = 0xc4,	/* Modula 2 scope info (Sun) */
-    N_RBRAC = 0xe0,	/* End of lexical block */
-    N_BCOMM = 0xe2,	/* Begin named common block */
-    N_ECOMM = 0xe4,	/* End named common block */
-    N_ECOML = 0xe8,	/* Member of common block */
-    N_WITH = 0xea,	/* Pascal with statement: type,,0,0,offset (Solaris2) */
-    N_NBTEXT = 0xf0,	/* Gould non-base registers */
-    N_NBDATA = 0xf2,	/* Gould non-base registers */
-    N_NBBSS = 0xf4,	/* Gould non-base registers */
-    N_NBSTS = 0xf6,	/* Gould non-base registers */
-    N_NBLCS = 0xf8	/* Gould non-base registers */
+    N_UNDF = 0x00,      /* Undefined */
+    N_GSYM = 0x20,      /* Global symbol */
+    N_FNAME = 0x22,     /* Function name (BSD Fortran) */
+    N_FUN = 0x24,       /* Function name or Text segment variable */
+    N_STSYM = 0x26,     /* Data segment file-scope variable */
+    N_LCSYM = 0x28,     /* BSS segment file-scope variable */
+    N_MAIN = 0x2a,      /* Name of main routine */
+    N_ROSYM = 0x2c,     /* Variable in .rodata section */
+    N_PC = 0x30,        /* Global symbol (Pascal) */
+    N_SYMS = 0x32,      /* Number of symbols (Ultrix V4.0) */
+    N_NOMAP = 0x34,     /* No DST map */
+    N_OBJ = 0x38,       /* Object file (Solaris2) */
+    N_OPT = 0x3c,       /* Debugger options (Solaris2) */
+    N_RSYM = 0x40,      /* Register variable */
+    N_M2C = 0x42,       /* Modula-2 compilation unit */
+    N_SLINE = 0x44,     /* Line numbers in .text segment */
+    N_DSLINE = 0x46,    /* Line numbers in .data segment */
+    N_BSLINE = 0x48,    /* Line numbers in .bss segment */
+    N_BROWS = 0x48,     /* Source code .cb file's path */
+    N_DEFD = 0x4a,      /* GNU Modula-2 definition module dependency */
+    N_FLINE = 0x4c,     /* Function start/body/end line numbers (Solaris2) */
+    N_EHDECL = 0x50,    /* GNU C++ exception variable */
+    N_MOD2 = 0x50,      /* Modula2 info for imc (Ultrix V4.0) */
+    N_CATCH = 0x54,     /* GNU C++ catch clause */
+    N_SSYM = 0x60,      /* Structure or union element */
+    N_ENDM = 0x62,      /* Last stab for module (Solaris2) */
+    N_SO = 0x64,        /* Path and name of source files */
+    N_LSYM = 0x80,      /* Stack variable */
+    N_BINCL = 0x84,     /* Beginning of include file */
+    N_SOL = 0x84,       /* Name of include file */
+    N_PSYM = 0xa0,      /* Parameter variable */
+    N_EINCL = 0xa2,     /* End of include file */
+    N_ENTRY = 0xa4,     /* Alternate entry point */
+    N_LBRAC = 0xc0,     /* Beginning of lexical block */
+    N_EXCL = 0xc2,      /* Placeholder for a deleted include file */
+    N_SCOPE = 0xc4,     /* Modula 2 scope info (Sun) */
+    N_RBRAC = 0xe0,     /* End of lexical block */
+    N_BCOMM = 0xe2,     /* Begin named common block */
+    N_ECOMM = 0xe4,     /* End named common block */
+    N_ECOML = 0xe8,     /* Member of common block */
+    N_WITH = 0xea,      /* Pascal with statement: type,,0,0,offset (Solaris2) */
+    N_NBTEXT = 0xf0,    /* Gould non-base registers */
+    N_NBDATA = 0xf2,    /* Gould non-base registers */
+    N_NBBSS = 0xf4,     /* Gould non-base registers */
+    N_NBSTS = 0xf6,     /* Gould non-base registers */
+    N_NBLCS = 0xf8      /* Gould non-base registers */
 } stabs_stab_type;
 
 typedef struct yasm_dbgfmt_stabs {
-    yasm_dbgfmt_base dbgfmt;	    /* base structure */
+    yasm_dbgfmt_base dbgfmt;        /* base structure */
 } yasm_dbgfmt_stabs;
 
 typedef struct {
-    unsigned long lastline;	/* track line and file of bytecodes */
+    unsigned long lastline;     /* track line and file of bytecodes */
     unsigned long curline;
     const char *lastfile;
     const char *curfile;
 
-    unsigned int stablen;	/* size of a stab for current machine */
-    unsigned long stabcount;	/* count stored stabs; doesn't include first */
+    unsigned int stablen;       /* size of a stab for current machine */
+    unsigned long stabcount;    /* count stored stabs; doesn't include first */
 
-    yasm_section *stab;		/* sections to which stabs, stabstrs appended */
+    yasm_section *stab;         /* sections to which stabs, stabstrs appended */
     yasm_section *stabstr;
 
     yasm_bytecode *basebc;      /* base bytecode from which to track SLINEs */
@@ -104,20 +102,20 @@ typedef struct {
 } stabs_info;
 
 typedef struct {
-    /*@null@*/ yasm_bytecode *bcstr;	/* bytecode in stabstr for string */
-    stabs_stab_type type;		/* stab type: N_* */
-    unsigned char other;		/* unused, but stored here anyway */
-    unsigned short desc;		/* description element of a stab */
-    /*@null@*/ yasm_symrec *symvalue;	/* value element needing relocation */
-    /*@null@*/yasm_bytecode *bcvalue;	/* relocated stab's bytecode */
-    unsigned long value;		/* fallthrough value if above NULL */
+    /*@null@*/ yasm_bytecode *bcstr;    /* bytecode in stabstr for string */
+    stabs_stab_type type;               /* stab type: N_* */
+    unsigned char other;                /* unused, but stored here anyway */
+    unsigned short desc;                /* description element of a stab */
+    /*@null@*/ yasm_symrec *symvalue;   /* value element needing relocation */
+    /*@null@*/yasm_bytecode *bcvalue;   /* relocated stab's bytecode */
+    unsigned long value;                /* fallthrough value if above NULL */
 } stabs_stab;
 
 /* Bytecode callback function prototypes */
 
 static void stabs_bc_str_destroy(void *contents);
 static void stabs_bc_str_print(const void *contents, FILE *f, int
-			       indent_level);
+                               indent_level);
 static int stabs_bc_str_calc_len
     (yasm_bytecode *bc, yasm_bc_add_span_func add_span, void *add_span_data);
 static int stabs_bc_str_tobytes
@@ -127,7 +125,7 @@ static int stabs_bc_str_tobytes
 
 static void stabs_bc_stab_destroy(void *contents);
 static void stabs_bc_stab_print(const void *contents, FILE *f, int
-				indent_level);
+                                indent_level);
 static int stabs_bc_stab_calc_len
     (yasm_bytecode *bc, yasm_bc_add_span_func add_span, void *add_span_data);
 static int stabs_bc_stab_tobytes
@@ -196,9 +194,9 @@ stabs_dbgfmt_append_bcstr(yasm_section *sect, const char *str)
 /* Requires a string bytecode, or NULL, for its string entry */
 static stabs_stab *
 stabs_dbgfmt_append_stab(stabs_info *info, yasm_section *sect,
-			 /*@null@*/ yasm_bytecode *bcstr, stabs_stab_type type,
-			 unsigned long desc, /*@null@*/ yasm_symrec *symvalue,
-			 /*@null@*/ yasm_bytecode *bcvalue, unsigned long value)
+                         /*@null@*/ yasm_bytecode *bcstr, stabs_stab_type type,
+                         unsigned long desc, /*@null@*/ yasm_symrec *symvalue,
+                         /*@null@*/ yasm_bytecode *bcvalue, unsigned long value)
 {
     yasm_bytecode *bc;
     stabs_stab *stab = yasm_xmalloc(sizeof(stabs_stab));
@@ -212,7 +210,7 @@ stabs_dbgfmt_append_stab(stabs_info *info, yasm_section *sect,
     stab->value = value;
 
     bc = yasm_bc_create_common(&stabs_bc_stab_callback, stab,
-			       bcvalue ? bcvalue->line : 0);
+                               bcvalue ? bcvalue->line : 0);
     bc->len = info->stablen;
     bc->offset = yasm_bc_next_offset(yasm_section_bcs_last(sect));
 
@@ -243,10 +241,10 @@ stabs_dbgfmt_generate_n_fun(stabs_info *info, yasm_bytecode *bc)
         str = yasm_xmalloc(strlen(name)+4);
         strcpy(str, name);
         strcat(str, ":F1");
-	stabs_dbgfmt_append_stab(info, info->stab,
-				 stabs_dbgfmt_append_bcstr(info->stabstr, str),
-				 N_FUN, 0, sym, info->basebc, 0);
-	yasm_xfree(str);
+        stabs_dbgfmt_append_stab(info, info->stab,
+                                 stabs_dbgfmt_append_bcstr(info->stabstr, str),
+                                 N_FUN, 0, sym, info->basebc, 0);
+        yasm_xfree(str);
         break;
     }
 }
@@ -256,24 +254,24 @@ stabs_dbgfmt_generate_bcs(yasm_bytecode *bc, void *d)
 {
     stabs_info *info = (stabs_info *)d;
     yasm_linemap_lookup(info->linemap, bc->line, &info->curfile,
-			&info->curline);
+                        &info->curline);
 
     /* check for new function */
     stabs_dbgfmt_generate_n_fun(info, bc);
 
     if (info->lastfile != info->curfile) {
-	info->lastline = 0; /* new file, so line changes */
-	/*stabs_dbgfmt_append_stab(info, info->stab,
-	    stabs_dbgfmt_append_bcstr(info->stabstr, info->curfile),
-	    N_SOL, 0, NULL, bc, 0);*/
+        info->lastline = 0; /* new file, so line changes */
+        /*stabs_dbgfmt_append_stab(info, info->stab,
+            stabs_dbgfmt_append_bcstr(info->stabstr, info->curfile),
+            N_SOL, 0, NULL, bc, 0);*/
     }
 
     /* output new line stabs if there's a basebc (known function) */
     if (info->basebc != NULL && info->curline != info->lastline) {
-	info->lastline = bc->line;
-	stabs_dbgfmt_append_stab(info, info->stab, NULL, N_SLINE,
-				 info->curline, NULL, NULL,
-				 bc->offset - info->basebc->offset);
+        info->lastline = bc->line;
+        stabs_dbgfmt_append_stab(info, info->stab, NULL, N_SLINE,
+                                 info->curline, NULL, NULL,
+                                 bc->offset - info->basebc->offset);
     }
 
     info->lastline = info->curline;
@@ -295,15 +293,15 @@ stabs_dbgfmt_generate_sections(yasm_section *sect, /*@null@*/ void *d)
     stabs_dbgfmt_generate_n_fun(d, yasm_section_bcs_first(sect));
 
     yasm_section_bcs_traverse(sect, info->errwarns, d,
-			      stabs_dbgfmt_generate_bcs);
+                              stabs_dbgfmt_generate_bcs);
 
     if (yasm__strcasecmp(sectname, ".text")==0) {
         /* Close out last function by appending a null SO stab after last bc */
         yasm_bytecode *bc = yasm_section_bcs_last(sect);
         yasm_symrec *sym =
-	    yasm_symtab_define_label(info->object->symtab, ".n_so", bc, 1,
-				     bc->line);
-	stabs_dbgfmt_append_stab(info, info->stab, 0, N_SO, 0, sym, bc, 0);
+            yasm_symtab_define_label(info->object->symtab, ".n_so", bc, 1,
+                                     bc->line);
+        stabs_dbgfmt_append_stab(info, info->stab, 0, N_SO, 0, sym, bc, 0);
     }
 
     return 1;
@@ -311,7 +309,7 @@ stabs_dbgfmt_generate_sections(yasm_section *sect, /*@null@*/ void *d)
 
 static void
 stabs_dbgfmt_generate(yasm_object *object, yasm_linemap *linemap,
-		      yasm_errwarns *errwarns)
+                      yasm_errwarns *errwarns)
 {
     stabs_info info;
     int new;
@@ -326,7 +324,7 @@ stabs_dbgfmt_generate(yasm_object *object, yasm_linemap *linemap,
         info.stablen = 12;
     }
     else /* unknown machine; generate nothing */
-	return;
+        return;
 
     info.object = object;
     info.linemap = linemap;
@@ -335,33 +333,33 @@ stabs_dbgfmt_generate(yasm_object *object, yasm_linemap *linemap,
     info.stabcount = 0;
     info.stab = yasm_object_get_general(object, ".stab", 0, 4, 0, 0, &new, 0);
     if (!new) {
-	yasm_bytecode *last = yasm_section_bcs_last(info.stab);
-	if (last == NULL) {
-	    yasm_error_set(YASM_ERROR_GENERAL,
-		N_("stabs debugging conflicts with user-defined section .stab"));
-	    yasm_errwarn_propagate(errwarns,
-				   yasm_section_bcs_first(info.stab)->line);
-	} else {
-	    yasm_warn_set(YASM_WARN_GENERAL,
-		N_("stabs debugging overrides empty section .stab"));
-	    yasm_errwarn_propagate(errwarns, 0);
-	}
+        yasm_bytecode *last = yasm_section_bcs_last(info.stab);
+        if (last == NULL) {
+            yasm_error_set(YASM_ERROR_GENERAL,
+                N_("stabs debugging conflicts with user-defined section .stab"));
+            yasm_errwarn_propagate(errwarns,
+                                   yasm_section_bcs_first(info.stab)->line);
+        } else {
+            yasm_warn_set(YASM_WARN_GENERAL,
+                N_("stabs debugging overrides empty section .stab"));
+            yasm_errwarn_propagate(errwarns, 0);
+        }
     }
 
     info.stabstr =
-	yasm_object_get_general(object, ".stabstr", 0, 1, 0, 0, &new, 0);
+        yasm_object_get_general(object, ".stabstr", 0, 1, 0, 0, &new, 0);
     if (!new) {
-	yasm_bytecode *last = yasm_section_bcs_last(info.stabstr);
-	if (last == NULL) {
-	    yasm_error_set(YASM_ERROR_GENERAL,
-		N_("stabs debugging conflicts with user-defined section .stabstr"));
-	    yasm_errwarn_propagate(errwarns,
-				   yasm_section_bcs_first(info.stab)->line);
-	} else {
-	    yasm_warn_set(YASM_WARN_GENERAL,
-		N_("stabs debugging overrides empty section .stabstr"));
-	    yasm_errwarn_propagate(errwarns, 0);
-	}
+        yasm_bytecode *last = yasm_section_bcs_last(info.stabstr);
+        if (last == NULL) {
+            yasm_error_set(YASM_ERROR_GENERAL,
+                N_("stabs debugging conflicts with user-defined section .stabstr"));
+            yasm_errwarn_propagate(errwarns,
+                                   yasm_section_bcs_first(info.stab)->line);
+        } else {
+            yasm_warn_set(YASM_WARN_GENERAL,
+                N_("stabs debugging overrides empty section .stabstr"));
+            yasm_errwarn_propagate(errwarns, 0);
+        }
     }
 
     /* initial pseudo-stab */
@@ -380,15 +378,15 @@ stabs_dbgfmt_generate(yasm_object *object, yasm_linemap *linemap,
     firstbc = yasm_section_bcs_first(stext);
     /* N_SO file stab */
     stabs_dbgfmt_append_stab(&info, info.stab, filebc, N_SO, 0,
-			     firstsym, firstbc, 0);
+                             firstsym, firstbc, 0);
 
     yasm_object_sections_traverse(object, (void *)&info,
-				  stabs_dbgfmt_generate_sections);
+                                  stabs_dbgfmt_generate_sections);
 
     /* fill initial pseudo-stab's fields */
     laststr = yasm_section_bcs_last(info.stabstr);
     if (laststr == NULL)
-	yasm_internal_error(".stabstr has no entries");
+        yasm_internal_error(".stabstr has no entries");
 
     stab->bcvalue = NULL;
     stab->symvalue = NULL;
@@ -397,17 +395,17 @@ stabs_dbgfmt_generate(yasm_object *object, yasm_linemap *linemap,
     stab->type = N_UNDF;
     stab->other = 0;
     if (info.stabcount > 0xffff) {
-	yasm_warn_set(YASM_WARN_GENERAL, N_("over 65535 stabs"));
-	yasm_errwarn_propagate(errwarns, 0);
-	stab->desc = 0xffff;
+        yasm_warn_set(YASM_WARN_GENERAL, N_("over 65535 stabs"));
+        yasm_errwarn_propagate(errwarns, 0);
+        stab->desc = 0xffff;
     } else
-	stab->desc = (unsigned short)info.stabcount;
+        stab->desc = (unsigned short)info.stabcount;
 }
 
 static int
 stabs_bc_stab_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
-		      yasm_output_value_func output_value,
-		      yasm_output_reloc_func output_reloc)
+                      yasm_output_value_func output_value,
+                      yasm_output_reloc_func output_reloc)
 {
     /* This entire function, essentially the core of rendering stabs to a file,
      * needs to become endian aware.  Size appears not to be an issue, as known
@@ -422,16 +420,16 @@ stabs_bc_stab_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
     YASM_WRITE_16_L(buf, stab->desc);
 
     if (stab->symvalue != NULL) {
-	bc->offset += 8;
-	output_reloc(stab->symvalue, bc, buf, 4, 32, 0, d);
-	bc->offset -= 8;
-	buf += 4;
+        bc->offset += 8;
+        output_reloc(stab->symvalue, bc, buf, 4, 32, 0, d);
+        bc->offset -= 8;
+        buf += 4;
     }
     else if (stab->bcvalue != NULL) {
-	YASM_WRITE_32_L(buf, stab->bcvalue->offset);
+        YASM_WRITE_32_L(buf, stab->bcvalue->offset);
     }
     else {
-	YASM_WRITE_32_L(buf, stab->value);
+        YASM_WRITE_32_L(buf, stab->value);
     }
 
     *bufp = buf;
@@ -440,8 +438,8 @@ stabs_bc_stab_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
 
 static int
 stabs_bc_str_tobytes(yasm_bytecode *bc, unsigned char **bufp, void *d,
-		     yasm_output_value_func output_value,
-		     yasm_output_reloc_func output_reloc)
+                     yasm_output_value_func output_value,
+                     yasm_output_reloc_func output_reloc)
 {
     const char *str = (const char *)bc->contents;
     unsigned char *buf = *bufp;
@@ -471,8 +469,8 @@ stabs_bc_stab_print(const void *contents, FILE *f, int indent_level)
     const stabs_stab *stab = (const stabs_stab *)contents;
     const char *str = "";
     fprintf(f, "%*s.stabs \"%s\", 0x%x, 0x%x, 0x%x, 0x%lx\n",
-	    indent_level, "", str, stab->type, stab->other, stab->desc,
-	    stab->bcvalue ? stab->bcvalue->offset : stab->value);
+            indent_level, "", str, stab->type, stab->other, stab->desc,
+            stab->bcvalue ? stab->bcvalue->offset : stab->value);
 }
 
 static void
@@ -483,7 +481,7 @@ stabs_bc_str_print(const void *contents, FILE *f, int indent_level)
 
 static int
 stabs_bc_stab_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
-		       void *add_span_data)
+                       void *add_span_data)
 {
     yasm_internal_error(N_("tried to resolve a stabs stab bytecode"));
     /*@notreached@*/
@@ -492,7 +490,7 @@ stabs_bc_stab_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
 
 static int
 stabs_bc_str_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
-		      void *add_span_data)
+                      void *add_span_data)
 {
     yasm_internal_error(N_("tried to resolve a stabs str bytecode"));
     /*@notreached@*/
@@ -503,7 +501,7 @@ stabs_bc_str_calc_len(yasm_bytecode *bc, yasm_bc_add_span_func add_span,
 yasm_dbgfmt_module yasm_stabs_LTX_dbgfmt = {
     "Stabs debugging format",
     "stabs",
-    NULL,	/* no directives */
+    NULL,       /* no directives */
     stabs_dbgfmt_create,
     stabs_dbgfmt_destroy,
     stabs_dbgfmt_generate
