@@ -25,18 +25,15 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: bin-objfmt.c 1879 2007-06-05 04:20:37Z peter $");
+/*@unused@*/ RCSID("$Id: bin-objfmt.c 1974 2007-09-21 16:37:01Z peter $");
 
-#define YASM_LIB_INTERNAL
-#define YASM_BC_INTERNAL
-#define YASM_EXPR_INTERNAL
 #include <libyasm.h>
 
 
-#define REGULAR_OUTBUF_SIZE	1024
+#define REGULAR_OUTBUF_SIZE     1024
 
 typedef struct yasm_objfmt_bin {
-    yasm_objfmt_base objfmt;		/* base structure */
+    yasm_objfmt_base objfmt;            /* base structure */
 } yasm_objfmt_bin;
 
 yasm_objfmt_module yasm_bin_LTX_objfmt;
@@ -56,9 +53,9 @@ bin_objfmt_create(yasm_object *object)
  */
 static unsigned long
 bin_objfmt_align_section(yasm_section *sect, yasm_section *prevsect,
-			 unsigned long base,
-			 /*@out@*/ unsigned long *prevsectlen,
-			 /*@out@*/ unsigned long *padamt)
+                         unsigned long base,
+                         /*@out@*/ unsigned long *prevsectlen,
+                         /*@out@*/ unsigned long *padamt)
 {
     unsigned long start;
     unsigned long align;
@@ -76,7 +73,7 @@ bin_objfmt_align_section(yasm_section *sect, yasm_section *prevsect,
     align = yasm_section_get_align(sect);
 
     if (start & (align-1))
-	start = (start & ~(align-1)) + align;
+        start = (start & ~(align-1)) + align;
 
     *padamt = start - (base + *prevsectlen);
 
@@ -89,13 +86,13 @@ typedef struct bin_objfmt_output_info {
     /*@dependent@*/ FILE *f;
     /*@only@*/ unsigned char *buf;
     /*@observer@*/ const yasm_section *sect;
-    unsigned long start;	/* what normal variables go against */
-    unsigned long abs_start;	/* what absolutes go against */
+    unsigned long start;        /* what normal variables go against */
+    unsigned long abs_start;    /* what absolutes go against */
 } bin_objfmt_output_info;
 
 static /*@only@*/ yasm_expr *
 bin_objfmt_expr_xform(/*@returned@*/ /*@only@*/ yasm_expr *e,
-		      /*@unused@*/ /*@null@*/ void *d)
+                      /*@unused@*/ /*@null@*/ void *d)
 {
     int i;
     /*@dependent@*/ yasm_section *sect;
@@ -104,21 +101,21 @@ bin_objfmt_expr_xform(/*@returned@*/ /*@only@*/ yasm_expr *e,
 
     for (i=0; i<e->numterms; i++) {
         /* Transform symrecs or precbcs that reference sections into
-	 * start expr + intnum(dist).
-	 */
+         * start expr + intnum(dist).
+         */
         if (((e->terms[i].type == YASM_EXPR_SYM &&
              yasm_symrec_get_label(e->terms[i].data.sym, &precbc)) ||
             (e->terms[i].type == YASM_EXPR_PRECBC &&
              (precbc = e->terms[i].data.precbc))) &&
-	    (sect = yasm_bc_get_section(precbc)) &&
-	    (dist = yasm_calc_bc_dist(yasm_section_bcs_first(sect), precbc))) {
-	    const yasm_expr *start = yasm_section_get_start(sect);
-	    e->terms[i].type = YASM_EXPR_EXPR;
-	    e->terms[i].data.expn =
-		yasm_expr_create(YASM_EXPR_ADD,
-				 yasm_expr_expr(yasm_expr_copy(start)),
-				 yasm_expr_int(dist), e->line);
-	}
+            (sect = yasm_bc_get_section(precbc)) &&
+            (dist = yasm_calc_bc_dist(yasm_section_bcs_first(sect), precbc))) {
+            const yasm_expr *start = yasm_section_get_start(sect);
+            e->terms[i].type = YASM_EXPR_EXPR;
+            e->terms[i].data.expn =
+                yasm_expr_create(YASM_EXPR_ADD,
+                                 yasm_expr_expr(yasm_expr_copy(start)),
+                                 yasm_expr_int(dist), e->line);
+        }
     }
 
     return e;
@@ -126,9 +123,9 @@ bin_objfmt_expr_xform(/*@returned@*/ /*@only@*/ yasm_expr *e,
 
 static int
 bin_objfmt_output_value(yasm_value *value, unsigned char *buf,
-			unsigned int destsize,
-			/*@unused@*/ unsigned long offset, yasm_bytecode *bc,
-			int warn, /*@null@*/ void *d)
+                        unsigned int destsize,
+                        /*@unused@*/ unsigned long offset, yasm_bytecode *bc,
+                        int warn, /*@null@*/ void *d)
 {
     /*@null@*/ bin_objfmt_output_info *info = (bin_objfmt_output_info *)d;
     /*@dependent@*/ /*@null@*/ yasm_bytecode *precbc;
@@ -138,8 +135,8 @@ bin_objfmt_output_value(yasm_value *value, unsigned char *buf,
 
     /* Binary objects we need to resolve against object, not against section. */
     if (value->rel) {
-	unsigned int rshift = (unsigned int)value->rshift;
-	yasm_expr *syme;
+        unsigned int rshift = (unsigned int)value->rshift;
+        yasm_expr *syme;
 
         if (yasm_symrec_is_abs(value->rel)) {
             syme = yasm_expr_create_ident(yasm_expr_int(
@@ -160,42 +157,42 @@ bin_objfmt_output_value(yasm_value *value, unsigned char *buf,
                                     yasm_expr_expr(sube), bc->line);
             value->curpos_rel = 0;
             value->ip_rel = 0;
-        } else
+        }
 
-	if (value->rshift > 0)
+        if (value->rshift > 0)
             syme = yasm_expr_create(YASM_EXPR_SHR, yasm_expr_expr(syme),
-		yasm_expr_int(yasm_intnum_create_uint(rshift)), bc->line);
+                yasm_expr_int(yasm_intnum_create_uint(rshift)), bc->line);
 
         /* Add into absolute portion */
-	if (!value->abs)
-	    value->abs = syme;
-	else
-	    value->abs =
-		yasm_expr_create(YASM_EXPR_ADD, yasm_expr_expr(value->abs),
-				 yasm_expr_expr(syme), bc->line);
-	value->rel = NULL;
-	value->rshift = 0;
+        if (!value->abs)
+            value->abs = syme;
+        else
+            value->abs =
+                yasm_expr_create(YASM_EXPR_ADD, yasm_expr_expr(value->abs),
+                                 yasm_expr_expr(syme), bc->line);
+        value->rel = NULL;
+        value->rshift = 0;
     }
 done:
     /* Simplify absolute portion of value, transforming symrecs */
     if (value->abs)
-	value->abs = yasm_expr__level_tree
-	    (value->abs, 1, 1, 1, 0, bin_objfmt_expr_xform, NULL);
+        value->abs = yasm_expr__level_tree
+            (value->abs, 1, 1, 1, 0, bin_objfmt_expr_xform, NULL);
 
     /* Output */
     switch (yasm_value_output_basic(value, buf, destsize, bc, warn,
-				    info->object->arch)) {
-	case -1:
-	    return 1;
-	case 0:
-	    break;
-	default:
-	    return 0;
+                                    info->object->arch)) {
+        case -1:
+            return 1;
+        case 0:
+            break;
+        default:
+            return 0;
     }
 
     /* Couldn't output, assume it contains an external reference. */
     yasm_error_set(YASM_ERROR_GENERAL,
-	N_("binary object format does not support external references"));
+        N_("binary object format does not support external references"));
     return 1;
 }
 
@@ -210,36 +207,36 @@ bin_objfmt_output_bytecode(yasm_bytecode *bc, /*@null@*/ void *d)
     assert(info != NULL);
 
     bigbuf = yasm_bc_tobytes(bc, info->buf, &size, &gap, info,
-			     bin_objfmt_output_value, NULL);
+                             bin_objfmt_output_value, NULL);
 
     /* Don't bother doing anything else if size ended up being 0. */
     if (size == 0) {
-	if (bigbuf)
-	    yasm_xfree(bigbuf);
-	return 0;
+        if (bigbuf)
+            yasm_xfree(bigbuf);
+        return 0;
     }
 
     /* Warn that gaps are converted to 0 and write out the 0's. */
     if (gap) {
-	unsigned long left;
-	yasm_warn_set(YASM_WARN_UNINIT_CONTENTS,
-	    N_("uninitialized space declared in code/data section: zeroing"));
-	/* Write out in chunks */
-	memset(info->buf, 0, REGULAR_OUTBUF_SIZE);
-	left = size;
-	while (left > REGULAR_OUTBUF_SIZE) {
-	    fwrite(info->buf, REGULAR_OUTBUF_SIZE, 1, info->f);
-	    left -= REGULAR_OUTBUF_SIZE;
-	}
-	fwrite(info->buf, left, 1, info->f);
+        unsigned long left;
+        yasm_warn_set(YASM_WARN_UNINIT_CONTENTS,
+            N_("uninitialized space declared in code/data section: zeroing"));
+        /* Write out in chunks */
+        memset(info->buf, 0, REGULAR_OUTBUF_SIZE);
+        left = size;
+        while (left > REGULAR_OUTBUF_SIZE) {
+            fwrite(info->buf, REGULAR_OUTBUF_SIZE, 1, info->f);
+            left -= REGULAR_OUTBUF_SIZE;
+        }
+        fwrite(info->buf, left, 1, info->f);
     } else {
-	/* Output buf (or bigbuf if non-NULL) to file */
-	fwrite(bigbuf ? bigbuf : info->buf, (size_t)size, 1, info->f);
+        /* Output buf (or bigbuf if non-NULL) to file */
+        fwrite(bigbuf ? bigbuf : info->buf, (size_t)size, 1, info->f);
     }
 
     /* If bigbuf was allocated, free it */
     if (bigbuf)
-	yasm_xfree(bigbuf);
+        yasm_xfree(bigbuf);
 
     return 0;
 }
@@ -252,24 +249,24 @@ bin_objfmt_check_sym(yasm_symrec *sym, /*@null@*/ void *d)
     assert(info != NULL);
 
     if (vis & YASM_SYM_EXTERN) {
-	yasm_warn_set(YASM_WARN_GENERAL,
-	    N_("binary object format does not support extern variables"));
-	yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
+        yasm_warn_set(YASM_WARN_GENERAL,
+            N_("binary object format does not support extern variables"));
+        yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
     } else if (vis & YASM_SYM_GLOBAL) {
-	yasm_warn_set(YASM_WARN_GENERAL,
-	    N_("binary object format does not support global variables"));
-	yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
+        yasm_warn_set(YASM_WARN_GENERAL,
+            N_("binary object format does not support global variables"));
+        yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
     } else if (vis & YASM_SYM_COMMON) {
-	yasm_error_set(YASM_ERROR_TYPE,
-	    N_("binary object format does not support common variables"));
-	yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
+        yasm_error_set(YASM_ERROR_TYPE,
+            N_("binary object format does not support common variables"));
+        yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
     }
     return 0;
 }
 
 static void
 bin_objfmt_output(yasm_object *object, FILE *f, /*@unused@*/ int all_syms,
-		  yasm_errwarns *errwarns)
+                  yasm_errwarns *errwarns)
 {
     /*@observer@*/ /*@null@*/ yasm_section *text, *data, *bss, *prevsect;
     /*@null@*/ yasm_expr *startexpr;
@@ -293,7 +290,7 @@ bin_objfmt_output(yasm_object *object, FILE *f, /*@unused@*/ int all_syms,
     bss = yasm_object_find_general(object, ".bss");
 
     if (!text)
-	yasm_internal_error(N_("No `.text' section in bin objfmt output"));
+        yasm_internal_error(N_("No `.text' section in bin objfmt output"));
 
     /* First determine the actual starting offsets for .data and .bss.
      * As the order in the file is .text -> .data -> .bss (not present),
@@ -307,10 +304,10 @@ bin_objfmt_output(yasm_object *object, FILE *f, /*@unused@*/ int all_syms,
     assert(startexpr != NULL);
     startnum = yasm_expr_get_intnum(&startexpr, 0);
     if (!startnum) {
-	yasm_error_set(YASM_ERROR_TOO_COMPLEX,
-		       N_("ORG expression too complex"));
-	yasm_errwarn_propagate(errwarns, startexpr->line);
-	return;
+        yasm_error_set(YASM_ERROR_TOO_COMPLEX,
+                       N_("ORG expression too complex"));
+        yasm_errwarn_propagate(errwarns, startexpr->line);
+        return;
     }
     start = yasm_intnum_get_uint(startnum);
     yasm_expr_destroy(startexpr);
@@ -322,41 +319,41 @@ bin_objfmt_output(yasm_object *object, FILE *f, /*@unused@*/ int all_syms,
     prevsectlenptr = &textlen;
     prevsectpadptr = &textpad;
     if (data) {
-	start = bin_objfmt_align_section(data, prevsect, start,
-					 prevsectlenptr, prevsectpadptr);
-	yasm_section_set_start(data, yasm_expr_create_ident(
-	    yasm_expr_int(yasm_intnum_create_uint(start)), 0), 0);
-	datastart = start;
-	prevsect = data;
-	prevsectlenptr = &datalen;
-	prevsectpadptr = &datapad;
+        start = bin_objfmt_align_section(data, prevsect, start,
+                                         prevsectlenptr, prevsectpadptr);
+        yasm_section_set_start(data, yasm_expr_create_ident(
+            yasm_expr_int(yasm_intnum_create_uint(start)), 0), 0);
+        datastart = start;
+        prevsect = data;
+        prevsectlenptr = &datalen;
+        prevsectpadptr = &datapad;
     }
     if (bss) {
-	start = bin_objfmt_align_section(bss, prevsect, start,
-					 prevsectlenptr, prevsectpadptr);
-	yasm_section_set_start(bss, yasm_expr_create_ident(
-	    yasm_expr_int(yasm_intnum_create_uint(start)), 0), 0);
+        start = bin_objfmt_align_section(bss, prevsect, start,
+                                         prevsectlenptr, prevsectpadptr);
+        yasm_section_set_start(bss, yasm_expr_create_ident(
+            yasm_expr_int(yasm_intnum_create_uint(start)), 0), 0);
     }
 
     /* Output .text first. */
     info.sect = text;
     info.start = textstart;
     yasm_section_bcs_traverse(text, errwarns, &info,
-			      bin_objfmt_output_bytecode);
+                              bin_objfmt_output_bytecode);
 
     /* If .data is present, output it */
     if (data) {
-	/* Add padding to align .data.  Just use a for loop, as this will
-	 * seldom be very many bytes.
-	 */
-	for (i=0; i<textpad; i++)
-	    fputc(0, f);
+        /* Add padding to align .data.  Just use a for loop, as this will
+         * seldom be very many bytes.
+         */
+        for (i=0; i<textpad; i++)
+            fputc(0, f);
 
-	/* Output .data bytecodes */
-	info.sect = data;
-	info.start = datastart;
-	yasm_section_bcs_traverse(data, errwarns,
-				  &info, bin_objfmt_output_bytecode);
+        /* Output .data bytecodes */
+        info.sect = data;
+        info.start = datastart;
+        yasm_section_bcs_traverse(data, errwarns,
+                                  &info, bin_objfmt_output_bytecode);
     }
 
     /* If .bss is present, check it for non-reserve bytecodes */
@@ -373,10 +370,10 @@ bin_objfmt_destroy(yasm_objfmt *objfmt)
 
 static void
 bin_objfmt_init_new_section(yasm_object *object, yasm_section *sect,
-			    const char *sectname, unsigned long line)
+                            const char *sectname, unsigned long line)
 {
     yasm_symtab_define_label(object->symtab, sectname,
-			     yasm_section_bcs_first(sect), 1, line);
+                             yasm_section_bcs_first(sect), 1, line);
 }
 
 static yasm_section *
@@ -387,17 +384,17 @@ bin_objfmt_add_default_section(yasm_object *object)
 
     retval = yasm_object_get_general(object, ".text", 0, 16, 1, 0, &isnew, 0);
     if (isnew) {
-	bin_objfmt_init_new_section(object, retval, ".text", 0);
-	yasm_section_set_default(retval, 1);
+        bin_objfmt_init_new_section(object, retval, ".text", 0);
+        yasm_section_set_default(retval, 1);
     }
     return retval;
 }
 
 static /*@observer@*/ /*@null@*/ yasm_section *
 bin_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
-			  /*@unused@*/ /*@null@*/
-			  yasm_valparamhead *objext_valparams,
-			  unsigned long line)
+                          /*@unused@*/ /*@null@*/
+                          yasm_valparamhead *objext_valparams,
+                          unsigned long line)
 {
     yasm_valparam *vp;
     yasm_section *retval;
@@ -419,22 +416,22 @@ bin_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
         return NULL;
     vp = yasm_vps_next(vp);
 
-	/* If it's the first section output (.text) start at 0, otherwise
-	 * make sure the start is > 128.
-	 */
-	if (strcmp(sectname, ".text") == 0)
-	    start = 0;
-	else if (strcmp(sectname, ".data") == 0)
-	    start = 200;
-	else if (strcmp(sectname, ".bss") == 0) {
-	    start = 200;
-	    resonly = 1;
-	} else {
-	    /* other section names not recognized. */
-	    yasm_error_set(YASM_ERROR_GENERAL,
-			   N_("segment name `%s' not recognized"), sectname);
-	    return NULL;
-	}
+    /* If it's the first section output (.text) start at 0, otherwise
+     * make sure the start is > 128.
+     */
+    if (strcmp(sectname, ".text") == 0)
+        start = 0;
+    else if (strcmp(sectname, ".data") == 0)
+        start = 200;
+    else if (strcmp(sectname, ".bss") == 0) {
+        start = 200;
+        resonly = 1;
+    } else {
+        /* other section names not recognized. */
+        yasm_error_set(YASM_ERROR_GENERAL,
+                       N_("segment name `%s' not recognized"), sectname);
+        return NULL;
+    }
 
     have_align = yasm_dir_helper(object, vp, line, help, NELEMS(help),
                                  &align_intn, yasm_dir_helper_valparam_warn);
@@ -445,38 +442,38 @@ bin_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
         align = yasm_intnum_get_uint(align_intn);
         yasm_intnum_destroy(align_intn);
 
-		/* Alignments must be a power of two. */
-		if (!is_exp2(align)) {
-		    yasm_error_set(YASM_ERROR_VALUE,
-				N_("argument to `%s' is not a power of two"),
+        /* Alignments must be a power of two. */
+        if (!is_exp2(align)) {
+            yasm_error_set(YASM_ERROR_VALUE,
+                           N_("argument to `%s' is not a power of two"),
                            "align");
-		    return NULL;
-		}
-	    }
+            return NULL;
+        }
+    }
 
-	retval = yasm_object_get_general(object, sectname,
-	    yasm_expr_create_ident(
-		yasm_expr_int(yasm_intnum_create_uint(start)), line), align,
-	    strcmp(sectname, ".text") == 0, resonly, &isnew, line);
+    retval = yasm_object_get_general(object, sectname,
+        yasm_expr_create_ident(
+            yasm_expr_int(yasm_intnum_create_uint(start)), line), align,
+        strcmp(sectname, ".text") == 0, resonly, &isnew, line);
 
-	if (isnew)
-	    bin_objfmt_init_new_section(object, retval, sectname, line);
+    if (isnew)
+        bin_objfmt_init_new_section(object, retval, sectname, line);
 
-	if (isnew || yasm_section_is_default(retval)) {
-	    yasm_section_set_default(retval, 0);
-	    yasm_section_set_align(retval, align, line);
-	} else if (have_align)
-	    yasm_warn_set(YASM_WARN_GENERAL,
-		N_("alignment value ignored on section redeclaration"));
+    if (isnew || yasm_section_is_default(retval)) {
+        yasm_section_set_default(retval, 0);
+        yasm_section_set_align(retval, align, line);
+    } else if (have_align)
+        yasm_warn_set(YASM_WARN_GENERAL,
+            N_("alignment value ignored on section redeclaration"));
 
-	return retval;
+    return retval;
 }
 
 static void
 bin_objfmt_dir_org(yasm_object *object,
-		   /*@null@*/ yasm_valparamhead *valparams,
-		   /*@unused@*/ /*@null@*/
-		   yasm_valparamhead *objext_valparams, unsigned long line)
+                   /*@null@*/ yasm_valparamhead *valparams,
+                   /*@unused@*/ /*@null@*/
+                   yasm_valparamhead *objext_valparams, unsigned long line)
 {
     yasm_section *sect;
     yasm_valparam *vp;
@@ -486,16 +483,16 @@ bin_objfmt_dir_org(yasm_object *object,
     vp = yasm_vps_first(valparams);
     start = yasm_vp_expr(vp, object->symtab, line);
     if (!start) {
-	yasm_error_set(YASM_ERROR_SYNTAX,
-		       N_("argument to ORG must be expression"));
-	return;
+        yasm_error_set(YASM_ERROR_SYNTAX,
+                       N_("argument to ORG must be expression"));
+        return;
     }
 
     /* ORG changes the start of the .text section */
     sect = yasm_object_find_general(object, ".text");
     if (!sect)
-	yasm_internal_error(
-	    N_("bin objfmt: .text section does not exist before ORG is called?"));
+        yasm_internal_error(
+            N_("bin objfmt: .text section does not exist before ORG is called?"));
     yasm_section_set_start(sect, start, line);
 }
 
@@ -507,7 +504,7 @@ static const char *bin_objfmt_dbgfmt_keywords[] = {
 };
 
 static const yasm_directive bin_objfmt_directives[] = {
-    { "org",	"nasm",	bin_objfmt_dir_org,	YASM_DIR_ARG_REQUIRED },
+    { "org",    "nasm", bin_objfmt_dir_org,     YASM_DIR_ARG_REQUIRED },
     { NULL, NULL, NULL, 0 }
 };
 
