@@ -26,10 +26,8 @@
  */
 
 #include <util.h>
-/*@unused@*/ RCSID("$Id: elf-x86-x86.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: elf-x86-x86.c 1976 2007-09-21 16:48:25Z peter $");
 
-#define YASM_LIB_INTERNAL
-#define YASM_EXPR_INTERNAL
 #include <libyasm.h>
 #define YASM_OBJFMT_ELF_INTERNAL
 #include "elf.h"
@@ -46,13 +44,13 @@ static int
 elf_x86_x86_accepts_reloc(size_t val, yasm_symrec *wrt, yasm_symrec **ssyms)
 {
     if (wrt) {
-	if ((wrt == ssyms[SSYM_GOTPC] && val == 32)
-	    || (wrt == ssyms[SSYM_GOTOFF] && val == 32)
-	    || (wrt == ssyms[SSYM_GOT] && val == 32)
-	    || (wrt == ssyms[SSYM_PLT] && val == 32))
-	    return 1;
-	else
-	    return 0;
+        if ((wrt == ssyms[SSYM_GOTPC] && val == 32)
+            || (wrt == ssyms[SSYM_GOTOFF] && val == 32)
+            || (wrt == ssyms[SSYM_GOT] && val == 32)
+            || (wrt == ssyms[SSYM_PLT] && val == 32))
+            return 1;
+        else
+            return 0;
     }
     return (val&(val-1)) ? 0 : ((val & (8|16|32)) != 0);
 }
@@ -111,11 +109,11 @@ elf_x86_x86_write_secthead_rel(unsigned char *bufp,
 
     YASM_WRITE_32_L(bufp, shead->rel_offset);
     YASM_WRITE_32_L(bufp, RELOC32_SIZE * shead->nreloc);/* size */
-    YASM_WRITE_32_L(bufp, symtab_idx);		/* link: symtab index */
-    YASM_WRITE_32_L(bufp, shead->index);	/* info: relocated's index */
+    YASM_WRITE_32_L(bufp, symtab_idx);          /* link: symtab index */
+    YASM_WRITE_32_L(bufp, shead->index);        /* info: relocated's index */
 
-    YASM_WRITE_32_L(bufp, RELOC32_ALIGN);	/* align */
-    YASM_WRITE_32_L(bufp, RELOC32_SIZE);	/* entity size */
+    YASM_WRITE_32_L(bufp, RELOC32_ALIGN);       /* align */
+    YASM_WRITE_32_L(bufp, RELOC32_SIZE);        /* entity size */
 }
 
 static void
@@ -126,19 +124,19 @@ elf_x86_x86_handle_reloc_addend(yasm_intnum *intn, elf_reloc_entry *reloc)
 
 static unsigned int
 elf_x86_x86_map_reloc_info_to_type(elf_reloc_entry *reloc,
-				   yasm_symrec **ssyms)
+                                   yasm_symrec **ssyms)
 {
     if (reloc->wrt) {
-	if (reloc->wrt == ssyms[SSYM_GOTPC] && reloc->valsize == 32)
-	    return (unsigned char) R_386_GOTPC;
-	else if (reloc->wrt == ssyms[SSYM_GOTOFF] && reloc->valsize == 32)
-	    return (unsigned char) R_386_GOTOFF;
-	else if (reloc->wrt == ssyms[SSYM_GOT] && reloc->valsize == 32)
-	    return (unsigned char) R_386_GOT32;
-	else if (reloc->wrt == ssyms[SSYM_PLT] && reloc->valsize == 32)
-	    return (unsigned char) R_386_PLT32;
-	else
-	    yasm_internal_error(N_("Unsupported WRT"));
+        if (reloc->wrt == ssyms[SSYM_GOTPC] && reloc->valsize == 32)
+            return (unsigned char) R_386_GOTPC;
+        else if (reloc->wrt == ssyms[SSYM_GOTOFF] && reloc->valsize == 32)
+            return (unsigned char) R_386_GOTOFF;
+        else if (reloc->wrt == ssyms[SSYM_GOT] && reloc->valsize == 32)
+            return (unsigned char) R_386_GOT32;
+        else if (reloc->wrt == ssyms[SSYM_PLT] && reloc->valsize == 32)
+            return (unsigned char) R_386_PLT32;
+        else
+            yasm_internal_error(N_("Unsupported WRT"));
     } else if (reloc->rtype_rel) {
         switch (reloc->valsize) {
             case 8: return (unsigned char) R_386_PC8;
@@ -173,32 +171,32 @@ elf_x86_x86_write_proghead(unsigned char **bufpp,
 {
     unsigned char *bufp = *bufpp;
     unsigned char *buf = bufp-4;
-    YASM_WRITE_8(bufp, ELFCLASS32);	    /* elf class */
-    YASM_WRITE_8(bufp, ELFDATA2LSB);	    /* data encoding :: MSB? */
-    YASM_WRITE_8(bufp, EV_CURRENT);	    /* elf version */
-    while (bufp-buf < EI_NIDENT)	    /* e_ident padding */
+    YASM_WRITE_8(bufp, ELFCLASS32);         /* elf class */
+    YASM_WRITE_8(bufp, ELFDATA2LSB);        /* data encoding :: MSB? */
+    YASM_WRITE_8(bufp, EV_CURRENT);         /* elf version */
+    while (bufp-buf < EI_NIDENT)            /* e_ident padding */
         YASM_WRITE_8(bufp, 0);
 
-    YASM_WRITE_16_L(bufp, ET_REL);	    /* e_type - object file */
-    YASM_WRITE_16_L(bufp, EM_386);	    /* e_machine - or others */
-    YASM_WRITE_32_L(bufp, EV_CURRENT);	    /* elf version */
-    YASM_WRITE_32_L(bufp, 0);		/* e_entry exection startaddr */
-    YASM_WRITE_32_L(bufp, 0);		/* e_phoff program header off */
+    YASM_WRITE_16_L(bufp, ET_REL);          /* e_type - object file */
+    YASM_WRITE_16_L(bufp, EM_386);          /* e_machine - or others */
+    YASM_WRITE_32_L(bufp, EV_CURRENT);      /* elf version */
+    YASM_WRITE_32_L(bufp, 0);           /* e_entry exection startaddr */
+    YASM_WRITE_32_L(bufp, 0);           /* e_phoff program header off */
     YASM_WRITE_32_L(bufp, secthead_addr);   /* e_shoff section header off */
-    YASM_WRITE_32_L(bufp, 0);		    /* e_flags also by arch */
-    YASM_WRITE_16_L(bufp, EHDR32_SIZE);	    /* e_ehsize */
-    YASM_WRITE_16_L(bufp, 0);		    /* e_phentsize */
-    YASM_WRITE_16_L(bufp, 0);		    /* e_phnum */
-    YASM_WRITE_16_L(bufp, SHDR32_SIZE);	    /* e_shentsize */
+    YASM_WRITE_32_L(bufp, 0);               /* e_flags also by arch */
+    YASM_WRITE_16_L(bufp, EHDR32_SIZE);     /* e_ehsize */
+    YASM_WRITE_16_L(bufp, 0);               /* e_phentsize */
+    YASM_WRITE_16_L(bufp, 0);               /* e_phnum */
+    YASM_WRITE_16_L(bufp, SHDR32_SIZE);     /* e_shentsize */
     YASM_WRITE_16_L(bufp, secthead_count);  /* e_shnum */
     YASM_WRITE_16_L(bufp, shstrtab_index);  /* e_shstrndx */
     *bufpp = bufp;
 }
 
 static elf_machine_ssym elf_x86_x86_ssyms[] = {
-    {"..gotpc", 0},
+    {"..gotpc", ELF_SSYM_CURPOS_ADJUST},
     {"..gotoff", 0},
-    {"..got", 1},
+    {"..got", ELF_SSYM_SYM_RELATIVE},
     {"..plt", 0}
 };
 
