@@ -25,82 +25,79 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: rdf-objfmt.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: rdf-objfmt.c 1974 2007-09-21 16:37:01Z peter $");
 
-#define YASM_LIB_INTERNAL
-#define YASM_BC_INTERNAL
-#define YASM_EXPR_INTERNAL
 #include <libyasm.h>
 
 
-#define REGULAR_OUTBUF_SIZE	1024
+#define REGULAR_OUTBUF_SIZE     1024
 
-#define RDF_MAGIC	"RDOFF2"
+#define RDF_MAGIC       "RDOFF2"
 
 /* Maximum size of an import/export label (including trailing zero) */
-#define EXIM_LABEL_MAX		64
+#define EXIM_LABEL_MAX          64
 
 /* Maximum size of library or module name (including trailing zero) */
-#define MODLIB_NAME_MAX		128
+#define MODLIB_NAME_MAX         128
 
 /* Maximum number of segments that we can handle in one file */
-#define RDF_MAXSEGS		64
+#define RDF_MAXSEGS             64
 
 /* Record types that may present the RDOFF header */
-#define RDFREC_GENERIC		0
-#define RDFREC_RELOC		1
-#define RDFREC_IMPORT		2
-#define RDFREC_GLOBAL		3
-#define RDFREC_DLL		4
-#define RDFREC_BSS		5
-#define RDFREC_SEGRELOC		6
-#define RDFREC_FARIMPORT	7
-#define RDFREC_MODNAME		8
-#define RDFREC_COMMON		10
+#define RDFREC_GENERIC          0
+#define RDFREC_RELOC            1
+#define RDFREC_IMPORT           2
+#define RDFREC_GLOBAL           3
+#define RDFREC_DLL              4
+#define RDFREC_BSS              5
+#define RDFREC_SEGRELOC         6
+#define RDFREC_FARIMPORT        7
+#define RDFREC_MODNAME          8
+#define RDFREC_COMMON           10
 
 /* Flags for ExportRec/ImportRec */
-#define SYM_DATA	1
-#define SYM_FUNCTION	2
+#define SYM_DATA        1
+#define SYM_FUNCTION    2
 
 /* Flags for ExportRec */
-#define SYM_GLOBAL	4
+#define SYM_GLOBAL      4
 
 /* Flags for ImportRec */
-#define SYM_IMPORT	8
-#define SYM_FAR		16
+#define SYM_IMPORT      8
+#define SYM_FAR         16
 
 typedef struct rdf_reloc {
     yasm_reloc reloc;
     enum {
-	RDF_RELOC_NORM,	    /* normal */
-	RDF_RELOC_REL,	    /* relative to current position */
-	RDF_RELOC_SEG	    /* segment containing symbol */
-    } type;			    /* type of relocation */
+        RDF_RELOC_NORM,     /* normal */
+        RDF_RELOC_REL,      /* relative to current position */
+        RDF_RELOC_SEG       /* segment containing symbol */
+    } type;                         /* type of relocation */
     unsigned int size;
     unsigned int refseg;
 } rdf_reloc;
 
 typedef struct rdf_section_data {
-    /*@dependent@*/ yasm_symrec *sym;	/* symbol created for this section */
-    long scnum;		    /* section number (0=first section) */
+    /*@dependent@*/ yasm_symrec *sym;   /* symbol created for this section */
+    long scnum;             /* section number (0=first section) */
     enum {
-	RDF_SECT_BSS = 0,
-	RDF_SECT_CODE = 1,
-	RDF_SECT_DATA = 2,
-	RDF_SECT_COMMENT = 3,
-	RDF_SECT_LCOMMENT = 4,
-	RDF_SECT_PCOMMENT = 5,
-	RDF_SECT_SYMDEBUG = 6,
-	RDF_SECT_LINEDEBUG = 7
-    } type;		    /* section type */
+        RDF_SECT_BSS = 0,
+        RDF_SECT_CODE = 1,
+        RDF_SECT_DATA = 2,
+        RDF_SECT_COMMENT = 3,
+        RDF_SECT_LCOMMENT = 4,
+        RDF_SECT_PCOMMENT = 5,
+        RDF_SECT_SYMDEBUG = 6,
+        RDF_SECT_LINEDEBUG = 7
+    } type;                 /* section type */
     unsigned int reserved;  /* reserved data */
-    unsigned long size;	    /* size of raw data (section data) in bytes */
+    unsigned long size;     /* size of raw data (section data) in bytes */
 
-    unsigned char *raw_data;	/* raw section data, only used during output */
+    unsigned char *raw_data;    /* raw section data, only used during output */
 } rdf_section_data;
 
 typedef struct rdf_symrec_data {
-    unsigned int segment;		/* assigned RDF "segment" index */
+    unsigned int segment;               /* assigned RDF "segment" index */
 } rdf_symrec_data;
 
 typedef STAILQ_HEAD(xdf_str_head, xdf_str) xdf_str_head;
@@ -110,9 +107,9 @@ typedef struct xdf_str {
 } xdf_str;
 
 typedef struct yasm_objfmt_rdf {
-    yasm_objfmt_base objfmt;		    /* base structure */
+    yasm_objfmt_base objfmt;                /* base structure */
 
-    long parse_scnum;		    /* sect numbering in parser */
+    long parse_scnum;               /* sect numbering in parser */
 
     /*@owned@*/ xdf_str_head module_names;
     /*@owned@*/ xdf_str_head library_names;
@@ -127,9 +124,9 @@ typedef struct rdf_objfmt_output_info {
     yasm_section *sect;
     /*@dependent@*/ rdf_section_data *rsd;
 
-    unsigned long indx;		    /* symbol "segment" (extern/common only) */
+    unsigned long indx;             /* symbol "segment" (extern/common only) */
 
-    unsigned long bss_size;	    /* total BSS size */
+    unsigned long bss_size;         /* total BSS size */
 } rdf_objfmt_output_info;
 
 static void rdf_section_data_destroy(/*@only@*/ void *d);
@@ -183,8 +180,8 @@ rdf_objfmt_create(yasm_object *object)
 
 static int
 rdf_objfmt_output_value(yasm_value *value, unsigned char *buf,
-			unsigned int destsize, unsigned long offset,
-			yasm_bytecode *bc, int warn, /*@null@*/ void *d)
+                        unsigned int destsize, unsigned long offset,
+                        yasm_bytecode *bc, int warn, /*@null@*/ void *d)
 {
     /*@null@*/ rdf_objfmt_output_info *info = (rdf_objfmt_output_info *)d;
     yasm_objfmt_rdf *objfmt_rdf;
@@ -198,102 +195,102 @@ rdf_objfmt_output_value(yasm_value *value, unsigned char *buf,
     objfmt_rdf = info->objfmt_rdf;
 
     if (value->abs)
-	value->abs = yasm_expr_simplify(value->abs, 1);
+        value->abs = yasm_expr_simplify(value->abs, 1);
 
     /* Try to output constant and PC-relative section-local first.
      * Note this does NOT output any value with a SEG, WRT, external,
      * cross-section, or non-PC-relative reference (those are handled below).
      */
     switch (yasm_value_output_basic(value, buf, destsize, bc, warn,
-				    info->object->arch)) {
-	case -1:
-	    return 1;
-	case 0:
-	    break;
-	default:
-	    return 0;
+                                    info->object->arch)) {
+        case -1:
+            return 1;
+        case 0:
+            break;
+        default:
+            return 0;
     }
 
     if (value->section_rel) {
-	yasm_error_set(YASM_ERROR_TOO_COMPLEX,
-		       N_("rdf: relocation too complex"));
-	return 1;
+        yasm_error_set(YASM_ERROR_TOO_COMPLEX,
+                       N_("rdf: relocation too complex"));
+        return 1;
     }
 
     if (value->rel && value->wrt) {
-	yasm_error_set(YASM_ERROR_TOO_COMPLEX,
-		       N_("rdf: WRT not supported"));
-	return 1;
+        yasm_error_set(YASM_ERROR_TOO_COMPLEX,
+                       N_("rdf: WRT not supported"));
+        return 1;
     }
 
     intn_minus = 0;
     intn_plus = 0;
     if (value->rel) {
-	rdf_reloc *reloc;
-	/*@null@*/ rdf_symrec_data *rsymd;
-	/*@dependent@*/ yasm_bytecode *precbc;
+        rdf_reloc *reloc;
+        /*@null@*/ rdf_symrec_data *rsymd;
+        /*@dependent@*/ yasm_bytecode *precbc;
 
-	reloc = yasm_xmalloc(sizeof(rdf_reloc));
-	reloc->reloc.addr = yasm_intnum_create_uint(bc->offset + offset);
-	reloc->reloc.sym = value->rel;
-	reloc->size = valsize/8;
+        reloc = yasm_xmalloc(sizeof(rdf_reloc));
+        reloc->reloc.addr = yasm_intnum_create_uint(bc->offset + offset);
+        reloc->reloc.sym = value->rel;
+        reloc->size = valsize/8;
 
-	if (value->seg_of)
-	    reloc->type = RDF_RELOC_SEG;
-	else if (value->curpos_rel) {
-	    reloc->type = RDF_RELOC_REL;
-	    /* Adjust to start of section, so subtract out the bytecode
-	     * offset.
-	     */
-	    intn_minus = bc->offset;
-	} else
-	    reloc->type = RDF_RELOC_NORM;
+        if (value->seg_of)
+            reloc->type = RDF_RELOC_SEG;
+        else if (value->curpos_rel) {
+            reloc->type = RDF_RELOC_REL;
+            /* Adjust to start of section, so subtract out the bytecode
+             * offset.
+             */
+            intn_minus = bc->offset;
+        } else
+            reloc->type = RDF_RELOC_NORM;
 
-	if (yasm_symrec_get_label(value->rel, &precbc)) {
-	    /* local, set the value to be the offset, and the refseg to the
-	     * segment number.
-	     */
-	    /*@dependent@*/ /*@null@*/ rdf_section_data *csectd;
-	    /*@dependent@*/ yasm_section *sect;
+        if (yasm_symrec_get_label(value->rel, &precbc)) {
+            /* local, set the value to be the offset, and the refseg to the
+             * segment number.
+             */
+            /*@dependent@*/ /*@null@*/ rdf_section_data *csectd;
+            /*@dependent@*/ yasm_section *sect;
 
-	    sect = yasm_bc_get_section(precbc);
-	    csectd = yasm_section_get_data(sect, &rdf_section_data_cb);
-	    if (!csectd)
-		yasm_internal_error(N_("didn't understand section"));
-	    reloc->refseg = csectd->scnum;
-	    intn_plus = yasm_bc_next_offset(precbc);
-	} else {
-	    /* must be common/external */
-	    rsymd = yasm_symrec_get_data(reloc->reloc.sym,
-					 &rdf_symrec_data_cb);
-	    if (!rsymd)
-		yasm_internal_error(
-		    N_("rdf: no symbol data for relocated symbol"));
-	    reloc->refseg = rsymd->segment;
-	}
+            sect = yasm_bc_get_section(precbc);
+            csectd = yasm_section_get_data(sect, &rdf_section_data_cb);
+            if (!csectd)
+                yasm_internal_error(N_("didn't understand section"));
+            reloc->refseg = csectd->scnum;
+            intn_plus = yasm_bc_next_offset(precbc);
+        } else {
+            /* must be common/external */
+            rsymd = yasm_symrec_get_data(reloc->reloc.sym,
+                                         &rdf_symrec_data_cb);
+            if (!rsymd)
+                yasm_internal_error(
+                    N_("rdf: no symbol data for relocated symbol"));
+            reloc->refseg = rsymd->segment;
+        }
 
-	yasm_section_add_reloc(info->sect, (yasm_reloc *)reloc, yasm_xfree);
+        yasm_section_add_reloc(info->sect, (yasm_reloc *)reloc, yasm_xfree);
     }
 
     if (intn_minus > 0) {
-	intn = yasm_intnum_create_uint(intn_minus);
-	yasm_intnum_calc(intn, YASM_EXPR_NEG, NULL);
+        intn = yasm_intnum_create_uint(intn_minus);
+        yasm_intnum_calc(intn, YASM_EXPR_NEG, NULL);
     } else
-	intn = yasm_intnum_create_uint(intn_plus);
+        intn = yasm_intnum_create_uint(intn_plus);
 
     if (value->abs) {
-	yasm_intnum *intn2 = yasm_expr_get_intnum(&value->abs, 0);
-	if (!intn2) {
-	    yasm_error_set(YASM_ERROR_TOO_COMPLEX,
-			   N_("rdf: relocation too complex"));
-	    yasm_intnum_destroy(intn);
-	    return 1;
-	}
-	yasm_intnum_calc(intn, YASM_EXPR_ADD, intn2);
+        yasm_intnum *intn2 = yasm_expr_get_intnum(&value->abs, 0);
+        if (!intn2) {
+            yasm_error_set(YASM_ERROR_TOO_COMPLEX,
+                           N_("rdf: relocation too complex"));
+            yasm_intnum_destroy(intn);
+            return 1;
+        }
+        yasm_intnum_calc(intn, YASM_EXPR_ADD, intn2);
     }
 
     retval = yasm_arch_intnum_tobytes(info->object->arch, intn, buf, destsize,
-				      valsize, 0, bc, warn);
+                                      valsize, 0, bc, warn);
     yasm_intnum_destroy(intn);
     return retval;
 }
@@ -309,32 +306,32 @@ rdf_objfmt_output_bytecode(yasm_bytecode *bc, /*@null@*/ void *d)
     assert(info != NULL);
 
     bigbuf = yasm_bc_tobytes(bc, info->buf, &size, &gap, info,
-			     rdf_objfmt_output_value, NULL);
+                             rdf_objfmt_output_value, NULL);
 
     /* Don't bother doing anything else if size ended up being 0. */
     if (size == 0) {
-	if (bigbuf)
-	    yasm_xfree(bigbuf);
-	return 0;
+        if (bigbuf)
+            yasm_xfree(bigbuf);
+        return 0;
     }
 
     /* Warn that gaps are converted to 0 and write out the 0's. */
     if (gap) {
-	yasm_warn_set(YASM_WARN_UNINIT_CONTENTS,
-		      N_("uninitialized space: zeroing"));
-	/* Write out in chunks */
-	memset(&info->rsd->raw_data[info->rsd->size], 0, size);
+        yasm_warn_set(YASM_WARN_UNINIT_CONTENTS,
+                      N_("uninitialized space: zeroing"));
+        /* Write out in chunks */
+        memset(&info->rsd->raw_data[info->rsd->size], 0, size);
     } else {
-	/* Output buf (or bigbuf if non-NULL) to file */
-	memcpy(&info->rsd->raw_data[info->rsd->size],
-	       bigbuf ? bigbuf : info->buf, (size_t)size);
+        /* Output buf (or bigbuf if non-NULL) to file */
+        memcpy(&info->rsd->raw_data[info->rsd->size],
+               bigbuf ? bigbuf : info->buf, (size_t)size);
     }
 
     info->rsd->size += size;
 
     /* If bigbuf was allocated, free it */
     if (bigbuf)
-	yasm_xfree(bigbuf);
+        yasm_xfree(bigbuf);
 
     return 0;
 }
@@ -353,16 +350,16 @@ rdf_objfmt_output_section_mem(yasm_section *sect, /*@null@*/ void *d)
     size = yasm_bc_next_offset(yasm_section_bcs_last(sect));
 
     if (rsd->type == RDF_SECT_BSS) {
-	/* Don't output BSS sections, but remember length
-	 * TODO: Check for non-reserve bytecodes?
-	 */
-	info->bss_size += size;
-	return 0;
+        /* Don't output BSS sections, but remember length
+         * TODO: Check for non-reserve bytecodes?
+         */
+        info->bss_size += size;
+        return 0;
     }
 
     /* Empty?  Go on to next section */
     if (size == 0)
-	return 0;
+        return 0;
 
     /* See UGH comment in output() for why we're doing this */
     rsd->raw_data = yasm_xmalloc(size);
@@ -371,12 +368,12 @@ rdf_objfmt_output_section_mem(yasm_section *sect, /*@null@*/ void *d)
     info->sect = sect;
     info->rsd = rsd;
     yasm_section_bcs_traverse(sect, info->errwarns, info,
-			      rdf_objfmt_output_bytecode);
+                              rdf_objfmt_output_bytecode);
 
     /* Sanity check final section size */
     if (rsd->size != size)
-	yasm_internal_error(
-	    N_("rdf: section computed size did not match actual size"));
+        yasm_internal_error(
+            N_("rdf: section computed size did not match actual size"));
 
     return 0;
 }
@@ -393,33 +390,33 @@ rdf_objfmt_output_section_reloc(yasm_section *sect, /*@null@*/ void *d)
     assert(rsd != NULL);
 
     if (rsd->type == RDF_SECT_BSS) {
-	/* Don't output BSS sections. */
-	return 0;
+        /* Don't output BSS sections. */
+        return 0;
     }
 
     /* Empty?  Go on to next section */
     if (rsd->size == 0)
-	return 0;
+        return 0;
 
     reloc = (rdf_reloc *)yasm_section_relocs_first(sect);
     while (reloc) {
-	unsigned char *localbuf = info->buf;
+        unsigned char *localbuf = info->buf;
 
-	if (reloc->type == RDF_RELOC_SEG)
-	    YASM_WRITE_8(localbuf, RDFREC_SEGRELOC);
-	else
-	    YASM_WRITE_8(localbuf, RDFREC_RELOC);
-	YASM_WRITE_8(localbuf, 8);		/* record length */
-	/* Section number, +0x40 if relative reloc */
-	YASM_WRITE_8(localbuf, rsd->scnum +
-		     (reloc->type == RDF_RELOC_REL ? 0x40 : 0));
-	yasm_intnum_get_sized(reloc->reloc.addr, localbuf, 4, 32, 0, 0, 0);
-	localbuf += 4;				/* offset of relocation */
-	YASM_WRITE_8(localbuf, reloc->size);	    /* size of relocation */
-	YASM_WRITE_16_L(localbuf, reloc->refseg);   /* relocated symbol */
-	fwrite(info->buf, 10, 1, info->f);
+        if (reloc->type == RDF_RELOC_SEG)
+            YASM_WRITE_8(localbuf, RDFREC_SEGRELOC);
+        else
+            YASM_WRITE_8(localbuf, RDFREC_RELOC);
+        YASM_WRITE_8(localbuf, 8);              /* record length */
+        /* Section number, +0x40 if relative reloc */
+        YASM_WRITE_8(localbuf, rsd->scnum +
+                     (reloc->type == RDF_RELOC_REL ? 0x40 : 0));
+        yasm_intnum_get_sized(reloc->reloc.addr, localbuf, 4, 32, 0, 0, 0);
+        localbuf += 4;                          /* offset of relocation */
+        YASM_WRITE_8(localbuf, reloc->size);        /* size of relocation */
+        YASM_WRITE_16_L(localbuf, reloc->refseg);   /* relocated symbol */
+        fwrite(info->buf, 10, 1, info->f);
 
-	reloc = (rdf_reloc *)yasm_section_reloc_next((yasm_reloc *)reloc);
+        reloc = (rdf_reloc *)yasm_section_reloc_next((yasm_reloc *)reloc);
     }
 
     return 0;
@@ -437,20 +434,20 @@ rdf_objfmt_output_section_file(yasm_section *sect, /*@null@*/ void *d)
     assert(rsd != NULL);
 
     if (rsd->type == RDF_SECT_BSS) {
-	/* Don't output BSS sections. */
-	return 0;
+        /* Don't output BSS sections. */
+        return 0;
     }
 
     /* Empty?  Go on to next section */
     if (rsd->size == 0)
-	return 0;
+        return 0;
 
     /* Section header */
     localbuf = info->buf;
-    YASM_WRITE_16_L(localbuf, rsd->type);	/* type */
-    YASM_WRITE_16_L(localbuf, rsd->scnum);	/* number */
-    YASM_WRITE_16_L(localbuf, rsd->reserved);	/* reserved */
-    YASM_WRITE_32_L(localbuf, rsd->size);	/* length */
+    YASM_WRITE_16_L(localbuf, rsd->type);       /* type */
+    YASM_WRITE_16_L(localbuf, rsd->scnum);      /* number */
+    YASM_WRITE_16_L(localbuf, rsd->reserved);   /* reserved */
+    YASM_WRITE_32_L(localbuf, rsd->size);       /* length */
     fwrite(info->buf, 10, 1, info->f);
 
     /* Section data */
@@ -491,7 +488,7 @@ static unsigned int
 rdf_parse_flags(yasm_symrec *sym)
 {
     /*@dependent@*/ /*@null@*/ yasm_valparamhead *objext_valparams =
-	yasm_symrec_get_objext_valparams(sym);
+        yasm_symrec_get_objext_valparams(sym);
     unsigned int flags = 0;
 
     static const yasm_dir_help help[] = {
@@ -510,7 +507,7 @@ rdf_parse_flags(yasm_symrec *sym)
     };
 
     if (!objext_valparams)
-	return 0;
+        return 0;
 
     yasm_dir_helper(sym, yasm_vps_first(objext_valparams), 0, help,
                     NELEMS(help), &flags, yasm_dir_helper_valparam_warn);
@@ -534,81 +531,81 @@ rdf_objfmt_output_sym(yasm_symrec *sym, /*@null@*/ void *d)
     assert(info != NULL);
 
     if (vis == YASM_SYM_LOCAL || vis == YASM_SYM_DLOCAL)
-	return 0;   /* skip local syms */
+        return 0;   /* skip local syms */
 
     /* Look at symrec for value/scnum/etc. */
     if (yasm_symrec_get_label(sym, &precbc)) {
-	/*@dependent@*/ /*@null@*/ rdf_section_data *csectd;
+        /*@dependent@*/ /*@null@*/ rdf_section_data *csectd;
 
-	if (precbc)
-	    sect = yasm_bc_get_section(precbc);
-	else
-	    sect = NULL;
-	if (!sect)
-	    return 0;
+        if (precbc)
+            sect = yasm_bc_get_section(precbc);
+        else
+            sect = NULL;
+        if (!sect)
+            return 0;
 
-	/* it's a label: get value and offset. */
-	csectd = yasm_section_get_data(sect, &rdf_section_data_cb);
-	if (csectd)
-	    scnum = csectd->scnum;
-	else
-	    yasm_internal_error(N_("didn't understand section"));
-	value = yasm_bc_next_offset(precbc);
+        /* it's a label: get value and offset. */
+        csectd = yasm_section_get_data(sect, &rdf_section_data_cb);
+        if (csectd)
+            scnum = csectd->scnum;
+        else
+            yasm_internal_error(N_("didn't understand section"));
+        value = yasm_bc_next_offset(precbc);
     } else if (yasm_symrec_get_equ(sym)) {
-	yasm_warn_set(YASM_WARN_GENERAL,
-	    N_("rdf does not support exporting EQU/absolute values"));
-	yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
-	return 0;
+        yasm_warn_set(YASM_WARN_GENERAL,
+            N_("rdf does not support exporting EQU/absolute values"));
+        yasm_errwarn_propagate(info->errwarns, yasm_symrec_get_decl_line(sym));
+        return 0;
     }
 
     name = yasm_symrec_get_name(sym);
     len = strlen(name);
 
     if (len > EXIM_LABEL_MAX-1) {
-	yasm_warn_set(YASM_WARN_GENERAL,
-		      N_("label name too long, truncating to %d bytes"),
-		      EXIM_LABEL_MAX);
-	len = EXIM_LABEL_MAX-1;
+        yasm_warn_set(YASM_WARN_GENERAL,
+                      N_("label name too long, truncating to %d bytes"),
+                      EXIM_LABEL_MAX);
+        len = EXIM_LABEL_MAX-1;
     }
 
     localbuf = info->buf;
     if (vis & YASM_SYM_GLOBAL) {
-	YASM_WRITE_8(localbuf, RDFREC_GLOBAL);
-	YASM_WRITE_8(localbuf, 6+len+1);	/* record length */
-	YASM_WRITE_8(localbuf, rdf_parse_flags(sym));	/* flags */
-	YASM_WRITE_8(localbuf, scnum);		/* segment referred to */
-	YASM_WRITE_32_L(localbuf, value);	/* offset */
+        YASM_WRITE_8(localbuf, RDFREC_GLOBAL);
+        YASM_WRITE_8(localbuf, 6+len+1);        /* record length */
+        YASM_WRITE_8(localbuf, rdf_parse_flags(sym));   /* flags */
+        YASM_WRITE_8(localbuf, scnum);          /* segment referred to */
+        YASM_WRITE_32_L(localbuf, value);       /* offset */
     } else {
-	/* Save symbol segment in symrec data (for later reloc gen) */
-	scnum = info->indx++;
-	rdf_objfmt_sym_set_data(sym, scnum);
+        /* Save symbol segment in symrec data (for later reloc gen) */
+        scnum = info->indx++;
+        rdf_objfmt_sym_set_data(sym, scnum);
 
-	if (vis & YASM_SYM_COMMON) {
-	    /*@dependent@*/ /*@null@*/ yasm_expr **csize_expr;
-	    const yasm_intnum *intn;
-	    /*@dependent@*/ /*@null@*/ yasm_valparamhead *objext_valparams =
-		yasm_symrec_get_objext_valparams(sym);
-	    unsigned long addralign = 0;
+        if (vis & YASM_SYM_COMMON) {
+            /*@dependent@*/ /*@null@*/ yasm_expr **csize_expr;
+            const yasm_intnum *intn;
+            /*@dependent@*/ /*@null@*/ yasm_valparamhead *objext_valparams =
+                yasm_symrec_get_objext_valparams(sym);
+            unsigned long addralign = 0;
 
-	    YASM_WRITE_8(localbuf, RDFREC_COMMON);
-	    YASM_WRITE_8(localbuf, 8+len+1);	/* record length */
-	    YASM_WRITE_16_L(localbuf, scnum);	/* segment allocated */
+            YASM_WRITE_8(localbuf, RDFREC_COMMON);
+            YASM_WRITE_8(localbuf, 8+len+1);    /* record length */
+            YASM_WRITE_16_L(localbuf, scnum);   /* segment allocated */
 
-	    /* size */
-	    csize_expr = yasm_symrec_get_common_size(sym);
-	    assert(csize_expr != NULL);
-	    intn = yasm_expr_get_intnum(csize_expr, 1);
-	    if (!intn) {
-		yasm_error_set(YASM_ERROR_NOT_CONSTANT,
-		    N_("COMMON data size not an integer expression"));
-	    } else
-		value = yasm_intnum_get_uint(intn);
-	    YASM_WRITE_32_L(localbuf, value);
+            /* size */
+            csize_expr = yasm_symrec_get_common_size(sym);
+            assert(csize_expr != NULL);
+            intn = yasm_expr_get_intnum(csize_expr, 1);
+            if (!intn) {
+                yasm_error_set(YASM_ERROR_NOT_CONSTANT,
+                    N_("COMMON data size not an integer expression"));
+            } else
+                value = yasm_intnum_get_uint(intn);
+            YASM_WRITE_32_L(localbuf, value);
 
-	    /* alignment */
-	    if (objext_valparams) {
-		yasm_valparam *vp = yasm_vps_first(objext_valparams);
-		for (; vp; vp = yasm_vps_next(vp)) {
+            /* alignment */
+            if (objext_valparams) {
+                yasm_valparam *vp = yasm_vps_first(objext_valparams);
+                for (; vp; vp = yasm_vps_next(vp)) {
                     if (!vp->val) {
                         /*@only@*/ /*@null@*/ yasm_expr *align_expr;
                         /*@dependent@*/ /*@null@*/
@@ -619,45 +616,45 @@ rdf_objfmt_output_sym(yasm_symrec *sym, /*@null@*/ void *d)
                                 yasm_symrec_get_decl_line(sym))) ||
                             !(align_intn = yasm_expr_get_intnum(&align_expr,
                                                                 0))) {
-			    yasm_error_set(YASM_ERROR_VALUE,
+                            yasm_error_set(YASM_ERROR_VALUE,
                                 N_("argument to `%s' is not an integer"),
                                 vp->val);
                             if (align_expr)
                                 yasm_expr_destroy(align_expr);
-			    continue;
-			}
+                            continue;
+                        }
                         addralign = yasm_intnum_get_uint(align_intn);
                         yasm_expr_destroy(align_expr);
 
-			/* Alignments must be a power of two. */
-			if (!is_exp2(addralign)) {
-			    yasm_error_set(YASM_ERROR_VALUE,
-				N_("alignment constraint is not a power of two"));
-			    continue;
-			}
+                        /* Alignments must be a power of two. */
+                        if (!is_exp2(addralign)) {
+                            yasm_error_set(YASM_ERROR_VALUE,
+                                N_("alignment constraint is not a power of two"));
+                            continue;
+                        }
                     } else
-			yasm_warn_set(YASM_WARN_GENERAL,
+                        yasm_warn_set(YASM_WARN_GENERAL,
                             N_("Unrecognized qualifier `%s'"), vp->val);
-		}
-	    }
-	    YASM_WRITE_16_L(localbuf, addralign);
-	} else if (vis & YASM_SYM_EXTERN) {
-	    unsigned int flags = rdf_parse_flags(sym);
-	    if (flags & SYM_FAR) {
-		YASM_WRITE_8(localbuf, RDFREC_FARIMPORT);
-		flags &= ~SYM_FAR;
-	    } else
-		YASM_WRITE_8(localbuf, RDFREC_IMPORT);
-	    YASM_WRITE_8(localbuf, 3+len+1);	/* record length */
-	    YASM_WRITE_8(localbuf, flags);	/* flags */
-	    YASM_WRITE_16_L(localbuf, scnum);	/* segment allocated */
-	}
+                }
+            }
+            YASM_WRITE_16_L(localbuf, addralign);
+        } else if (vis & YASM_SYM_EXTERN) {
+            unsigned int flags = rdf_parse_flags(sym);
+            if (flags & SYM_FAR) {
+                YASM_WRITE_8(localbuf, RDFREC_FARIMPORT);
+                flags &= ~SYM_FAR;
+            } else
+                YASM_WRITE_8(localbuf, RDFREC_IMPORT);
+            YASM_WRITE_8(localbuf, 3+len+1);    /* record length */
+            YASM_WRITE_8(localbuf, flags);      /* flags */
+            YASM_WRITE_16_L(localbuf, scnum);   /* segment allocated */
+        }
     }
 
     /* Symbol name */
     memcpy(localbuf, name, len);
     localbuf += len;
-    YASM_WRITE_8(localbuf, 0);		/* 0-terminated name */
+    YASM_WRITE_8(localbuf, 0);          /* 0-terminated name */
 
     fwrite(info->buf, (unsigned long)(localbuf-info->buf), 1, info->f);
 
@@ -667,7 +664,7 @@ rdf_objfmt_output_sym(yasm_symrec *sym, /*@null@*/ void *d)
 
 static void
 rdf_objfmt_output(yasm_object *object, FILE *f, int all_syms,
-		  yasm_errwarns *errwarns)
+                  yasm_errwarns *errwarns)
 {
     yasm_objfmt_rdf *objfmt_rdf = (yasm_objfmt_rdf *)object->objfmt;
     rdf_objfmt_output_info info;
@@ -685,32 +682,32 @@ rdf_objfmt_output(yasm_object *object, FILE *f, int all_syms,
 
     /* Allocate space for file header by seeking forward */
     if (fseek(f, (long)strlen(RDF_MAGIC)+8, SEEK_SET) < 0) {
-	yasm__fatal(N_("could not seek on output file"));
-	/*@notreached@*/
-	return;
+        yasm__fatal(N_("could not seek on output file"));
+        /*@notreached@*/
+        return;
     }
 
     /* Output custom header records (library and module, etc) */
     cur = STAILQ_FIRST(&objfmt_rdf->module_names);
     while (cur) {
-	len = strlen(cur->str)+1;
-	localbuf = info.buf;
-	YASM_WRITE_8(localbuf, RDFREC_MODNAME);		/* record type */
-	YASM_WRITE_8(localbuf, len);			/* record length */
-	fwrite(info.buf, 2, 1, f);
-	fwrite(cur->str, len, 1, f);
-	cur = STAILQ_NEXT(cur, link);
+        len = strlen(cur->str)+1;
+        localbuf = info.buf;
+        YASM_WRITE_8(localbuf, RDFREC_MODNAME);         /* record type */
+        YASM_WRITE_8(localbuf, len);                    /* record length */
+        fwrite(info.buf, 2, 1, f);
+        fwrite(cur->str, len, 1, f);
+        cur = STAILQ_NEXT(cur, link);
     }
 
     cur = STAILQ_FIRST(&objfmt_rdf->library_names);
     while (cur) {
-	len = strlen(cur->str)+1;
-	localbuf = info.buf;
-	YASM_WRITE_8(localbuf, RDFREC_DLL);		/* record type */
-	YASM_WRITE_8(localbuf, len);			/* record length */
-	fwrite(info.buf, 2, 1, f);
-	fwrite(cur->str, len, 1, f);
-	cur = STAILQ_NEXT(cur, link);
+        len = strlen(cur->str)+1;
+        localbuf = info.buf;
+        YASM_WRITE_8(localbuf, RDFREC_DLL);             /* record type */
+        YASM_WRITE_8(localbuf, len);                    /* record length */
+        fwrite(info.buf, 2, 1, f);
+        fwrite(cur->str, len, 1, f);
+        cur = STAILQ_NEXT(cur, link);
     }
 
     /* Output symbol table */
@@ -730,35 +727,35 @@ rdf_objfmt_output(yasm_object *object, FILE *f, int all_syms,
      * We also calculate the total size of all BSS sections here.
      */
     if (yasm_object_sections_traverse(object, &info,
-				      rdf_objfmt_output_section_mem))
-	return;
+                                      rdf_objfmt_output_section_mem))
+        return;
 
     /* Output all relocs */
     if (yasm_object_sections_traverse(object, &info,
-				      rdf_objfmt_output_section_reloc))
-	return;
+                                      rdf_objfmt_output_section_reloc))
+        return;
 
     /* Output BSS record */
     if (info.bss_size > 0) {
-	localbuf = info.buf;
-	YASM_WRITE_8(localbuf, RDFREC_BSS);		/* record type */
-	YASM_WRITE_8(localbuf, 4);			/* record length */
-	YASM_WRITE_32_L(localbuf, info.bss_size);	/* total BSS size */
-	fwrite(info.buf, 6, 1, f);
+        localbuf = info.buf;
+        YASM_WRITE_8(localbuf, RDFREC_BSS);             /* record type */
+        YASM_WRITE_8(localbuf, 4);                      /* record length */
+        YASM_WRITE_32_L(localbuf, info.bss_size);       /* total BSS size */
+        fwrite(info.buf, 6, 1, f);
     }
 
     /* Determine header length */
     headerlen = ftell(f);
     if (headerlen == -1) {
-	yasm__fatal(N_("could not get file position on output file"));
-	/*@notreached@*/
-	return;
+        yasm__fatal(N_("could not get file position on output file"));
+        /*@notreached@*/
+        return;
     }
 
     /* Section data (to file) */
     if (yasm_object_sections_traverse(object, &info,
-				      rdf_objfmt_output_section_file))
-	return;
+                                      rdf_objfmt_output_section_file))
+        return;
 
     /* NULL section to end file */
     memset(info.buf, 0, 10);
@@ -767,22 +764,22 @@ rdf_objfmt_output(yasm_object *object, FILE *f, int all_syms,
     /* Determine object length */
     filelen = ftell(f);
     if (filelen == -1) {
-	yasm__fatal(N_("could not get file position on output file"));
-	/*@notreached@*/
-	return;
+        yasm__fatal(N_("could not get file position on output file"));
+        /*@notreached@*/
+        return;
     }
 
     /* Write file header */
     if (fseek(f, 0, SEEK_SET) < 0) {
-	yasm__fatal(N_("could not seek on output file"));
-	/*@notreached@*/
-	return;
+        yasm__fatal(N_("could not seek on output file"));
+        /*@notreached@*/
+        return;
     }
 
     fwrite(RDF_MAGIC, strlen(RDF_MAGIC), 1, f);
     localbuf = info.buf;
-    YASM_WRITE_32_L(localbuf, filelen-10);		/* object size */
-    YASM_WRITE_32_L(localbuf, headerlen-14);		/* header size */
+    YASM_WRITE_32_L(localbuf, filelen-10);              /* object size */
+    YASM_WRITE_32_L(localbuf, headerlen-14);            /* header size */
     fwrite(info.buf, 8, 1, f);
 
     yasm_xfree(info.buf);
@@ -796,18 +793,18 @@ rdf_objfmt_destroy(yasm_objfmt *objfmt)
 
     cur = STAILQ_FIRST(&objfmt_rdf->module_names);
     while (cur) {
-	next = STAILQ_NEXT(cur, link);
-	yasm_xfree(cur->str);
-	yasm_xfree(cur);
-	cur = next;
+        next = STAILQ_NEXT(cur, link);
+        yasm_xfree(cur->str);
+        yasm_xfree(cur);
+        cur = next;
     }
 
     cur = STAILQ_FIRST(&objfmt_rdf->library_names);
     while (cur) {
-	next = STAILQ_NEXT(cur, link);
-	yasm_xfree(cur->str);
-	yasm_xfree(cur);
-	cur = next;
+        next = STAILQ_NEXT(cur, link);
+        yasm_xfree(cur->str);
+        yasm_xfree(cur);
+        cur = next;
     }
 
     yasm_xfree(objfmt);
@@ -815,7 +812,7 @@ rdf_objfmt_destroy(yasm_objfmt *objfmt)
 
 static rdf_section_data *
 rdf_objfmt_init_new_section(yasm_object *object, yasm_section *sect,
-			    const char *sectname, unsigned long line)
+                            const char *sectname, unsigned long line)
 {
     yasm_objfmt_rdf *objfmt_rdf = (yasm_objfmt_rdf *)object->objfmt;
     rdf_section_data *data;
@@ -830,7 +827,7 @@ rdf_objfmt_init_new_section(yasm_object *object, yasm_section *sect,
     yasm_section_add_data(sect, &rdf_section_data_cb, data);
 
     sym = yasm_symtab_define_label(object->symtab, sectname,
-				   yasm_section_bcs_first(sect), 1, line);
+                                   yasm_section_bcs_first(sect), 1, line);
     data->sym = sym;
     return data;
 }
@@ -844,10 +841,10 @@ rdf_objfmt_add_default_section(yasm_object *object)
 
     retval = yasm_object_get_general(object, ".text", 0, 0, 1, 0, &isnew, 0);
     if (isnew) {
-	rsd = rdf_objfmt_init_new_section(object, retval, ".text", 0);
-	rsd->type = RDF_SECT_CODE;
-	rsd->reserved = 0;
-	yasm_section_set_default(retval, 1);
+        rsd = rdf_objfmt_init_new_section(object, retval, ".text", 0);
+        rsd->type = RDF_SECT_CODE;
+        rsd->reserved = 0;
+        yasm_section_set_default(retval, 1);
     }
     return retval;
 }
@@ -880,9 +877,9 @@ rdf_helper_set_reserved(void *obj, yasm_valparam *vp, unsigned long line,
 
 static /*@observer@*/ /*@null@*/ yasm_section *
 rdf_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
-			  /*@unused@*/ /*@null@*/
-			  yasm_valparamhead *objext_valparams,
-			  unsigned long line)
+                          /*@unused@*/ /*@null@*/
+                          yasm_valparamhead *objext_valparams,
+                          unsigned long line)
 {
     yasm_valparam *vp = yasm_vps_first(valparams);
     yasm_section *retval;
@@ -923,7 +920,7 @@ rdf_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
     vp = yasm_vps_first(valparams);
     sectname = yasm_vp_string(vp);
     if (!sectname)
-	return NULL;
+        return NULL;
     vp = yasm_vps_next(vp);
 
     if (strcmp(sectname, ".text") == 0)
@@ -939,8 +936,8 @@ rdf_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
         return NULL;    /* error occurred */
 
     if (data.type == 0xffff) {
-	yasm_error_set(YASM_ERROR_VALUE,
-		       N_("new segment declared without type code"));
+        yasm_error_set(YASM_ERROR_VALUE,
+                       N_("new segment declared without type code"));
         data.type = RDF_SECT_DATA;
     }
 
@@ -953,17 +950,17 @@ rdf_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
                                      data.type == RDF_SECT_BSS, &isnew, line);
 
     if (isnew)
-	rsd = rdf_objfmt_init_new_section(object, retval, sectname, line);
+        rsd = rdf_objfmt_init_new_section(object, retval, sectname, line);
     else
-	rsd = yasm_section_get_data(retval, &rdf_section_data_cb);
+        rsd = yasm_section_get_data(retval, &rdf_section_data_cb);
 
     if (isnew || yasm_section_is_default(retval)) {
-	yasm_section_set_default(retval, 0);
+        yasm_section_set_default(retval, 0);
         rsd->type = data.type;
-	rsd->reserved = reserved;
+        rsd->reserved = reserved;
     } else if (flags_override)
-	yasm_warn_set(YASM_WARN_GENERAL,
-		      N_("section flags ignored on section redeclaration"));
+        yasm_warn_set(YASM_WARN_GENERAL,
+                      N_("section flags ignored on section redeclaration"));
     return retval;
 }
 
@@ -972,7 +969,7 @@ rdf_section_data_destroy(void *data)
 {
     rdf_section_data *rsd = (rdf_section_data *)data;
     if (rsd->raw_data)
-	yasm_xfree(rsd->raw_data);
+        yasm_xfree(rsd->raw_data);
     yasm_xfree(data);
 }
 
@@ -1013,21 +1010,21 @@ rdf_objfmt_add_libmodule(yasm_object *object, char *name, int lib)
     str = yasm_xmalloc(sizeof(xdf_str));
     str->str = name;
     if (lib)
-	STAILQ_INSERT_TAIL(&objfmt_rdf->library_names, str, link);
+        STAILQ_INSERT_TAIL(&objfmt_rdf->library_names, str, link);
     else
-	STAILQ_INSERT_TAIL(&objfmt_rdf->module_names, str, link);
+        STAILQ_INSERT_TAIL(&objfmt_rdf->module_names, str, link);
 
     if (strlen(str->str) > MODLIB_NAME_MAX-1) {
-	yasm_warn_set(YASM_WARN_GENERAL,
-		      N_("name too long, truncating to %d bytes"),
-		      MODLIB_NAME_MAX);
-	str->str[MODLIB_NAME_MAX-1] = '\0';
+        yasm_warn_set(YASM_WARN_GENERAL,
+                      N_("name too long, truncating to %d bytes"),
+                      MODLIB_NAME_MAX);
+        str->str[MODLIB_NAME_MAX-1] = '\0';
     }
 }
 
 static void
 dir_library(yasm_object *object, yasm_valparamhead *valparams,
-	    yasm_valparamhead *objext_valparams, unsigned long line)
+            yasm_valparamhead *objext_valparams, unsigned long line)
 {
     yasm_valparam *vp = yasm_vps_first(valparams);
     rdf_objfmt_add_libmodule(object, yasm__xstrdup(yasm_vp_string(vp)), 1);
@@ -1035,7 +1032,7 @@ dir_library(yasm_object *object, yasm_valparamhead *valparams,
 
 static void
 dir_module(yasm_object *object, yasm_valparamhead *valparams,
-	   yasm_valparamhead *objext_valparams, unsigned long line)
+           yasm_valparamhead *objext_valparams, unsigned long line)
 {
     yasm_valparam *vp = yasm_vps_first(valparams);
     rdf_objfmt_add_libmodule(object, yasm__xstrdup(yasm_vp_string(vp)), 0);
