@@ -28,32 +28,31 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: gas-parser.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: gas-parser.c 1978 2007-09-21 16:59:14Z peter $");
 
-#define YASM_LIB_INTERNAL
 #include <libyasm.h>
 
 #include "gas-parser.h"
 
 
 static void
-gas_parser_do_parse(yasm_object *object, yasm_preproc *pp, FILE *f,
-		    int save_input, yasm_linemap *linemap,
-		    yasm_errwarns *errwarns)
+gas_parser_do_parse(yasm_object *object, yasm_preproc *pp,
+                    int save_input, yasm_linemap *linemap,
+                    yasm_errwarns *errwarns)
 {
     yasm_parser_gas parser_gas;
+    int i;
 
     parser_gas.object = object;
     parser_gas.linemap = linemap;
 
-    parser_gas.in = f;
-
     parser_gas.locallabel_base = (char *)NULL;
     parser_gas.locallabel_base_len = 0;
 
     parser_gas.dir_fileline = 0;
     parser_gas.dir_file = NULL;
     parser_gas.dir_line = 0;
+    parser_gas.seen_line_marker = 0;
 
     parser_gas.preproc = pp;
     parser_gas.errwarns = errwarns;
@@ -72,6 +71,9 @@ gas_parser_do_parse(yasm_object *object, yasm_preproc *pp, FILE *f,
 
     parser_gas.rept = NULL;
 
+    for (i=0; i<10; i++)
+        parser_gas.local[i] = 0;
+
     /* yacc debugging, needs YYDEBUG set in bison.y.in to work */
     parser_gas.debug = 1;
 
@@ -79,28 +81,28 @@ gas_parser_do_parse(yasm_object *object, yasm_preproc *pp, FILE *f,
 
     /* Check for ending inside a rept */
     if (parser_gas.rept) {
-	yasm_error_set(YASM_ERROR_SYNTAX, N_("rept without matching endr"));
-	yasm_errwarn_propagate(errwarns, parser_gas.rept->startline);
+        yasm_error_set(YASM_ERROR_SYNTAX, N_("rept without matching endr"));
+        yasm_errwarn_propagate(errwarns, parser_gas.rept->startline);
     }
 
     /* Check for ending inside a comment */
     if (parser_gas.state == COMMENT) {
-	yasm_warn_set(YASM_WARN_GENERAL, N_("end of file in comment"));
-	/* XXX: Minus two to compensate for already having moved past the EOF
-	 * in the linemap.
-	 */
-	yasm_errwarn_propagate(errwarns,
-			       yasm_linemap_get_current(parser_gas.linemap)-2);
+        yasm_warn_set(YASM_WARN_GENERAL, N_("end of file in comment"));
+        /* XXX: Minus two to compensate for already having moved past the EOF
+         * in the linemap.
+         */
+        yasm_errwarn_propagate(errwarns,
+                               yasm_linemap_get_current(parser_gas.linemap)-2);
     }
 
     yasm_scanner_delete(&parser_gas.s);
 
     /* Free locallabel base if necessary */
     if (parser_gas.locallabel_base)
-	yasm_xfree(parser_gas.locallabel_base);
+        yasm_xfree(parser_gas.locallabel_base);
 
     if (parser_gas.dir_file)
-	yasm_xfree(parser_gas.dir_file);
+        yasm_xfree(parser_gas.dir_file);
 
     /* Convert all undefined symbols into extern symbols */
     yasm_symtab_parser_finalize(object->symtab, 1, errwarns);
@@ -109,6 +111,7 @@ gas_parser_do_parse(yasm_object *object, yasm_preproc *pp, FILE *f,
 /* Define valid preprocessors to use with this parser */
 static const char *gas_parser_preproc_keywords[] = {
     "raw",
+    "cpp",
     NULL
 };
 
