@@ -25,26 +25,23 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: nasm-parser.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: nasm-parser.c 1978 2007-09-21 16:59:14Z peter $");
 
-#define YASM_LIB_INTERNAL
 #include <libyasm.h>
 
 #include "nasm-parser.h"
 
 
 static void
-nasm_parser_do_parse(yasm_object *object, yasm_preproc *pp, FILE *f,
-		     int save_input, yasm_linemap *linemap,
-		     yasm_errwarns *errwarns)
+nasm_parser_do_parse(yasm_object *object, yasm_preproc *pp,
+                     int save_input, yasm_linemap *linemap,
+                     yasm_errwarns *errwarns)
 {
     yasm_parser_nasm parser_nasm;
 
     parser_nasm.object = object;
     parser_nasm.linemap = linemap;
 
-    parser_nasm.in = f;
-
     parser_nasm.locallabel_base = (char *)NULL;
     parser_nasm.locallabel_base_len = 0;
 
@@ -75,7 +72,7 @@ nasm_parser_do_parse(yasm_object *object, yasm_preproc *pp, FILE *f,
 
     /* Free locallabel base if necessary */
     if (parser_nasm.locallabel_base)
-	yasm_xfree(parser_nasm.locallabel_base);
+        yasm_xfree(parser_nasm.locallabel_base);
 
     /* Check for undefined symbols */
     yasm_symtab_parser_finalize(object->symtab, 0, errwarns);
