@@ -25,9 +25,8 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: raw-preproc.c 1876 2007-06-02 21:50:51Z peter $");
+/*@unused@*/ RCSID("$Id: raw-preproc.c 1978 2007-09-21 16:59:14Z peter $");
 
-#define YASM_LIB_INTERNAL
 #include <libyasm.h>
 
 
@@ -45,11 +44,20 @@ yasm_preproc_module yasm_raw_LTX_preproc;
 int isatty(int);
 
 static yasm_preproc *
-raw_preproc_create(FILE *f, const char *in_filename, yasm_linemap *lm,
-		   yasm_errwarns *errwarns)
+raw_preproc_create(const char *in_filename, yasm_linemap *lm,
+                   yasm_errwarns *errwarns)
 {
+    FILE *f;
     yasm_preproc_raw *preproc_raw = yasm_xmalloc(sizeof(yasm_preproc_raw));
 
+    if (strcmp(in_filename, "-") != 0) {
+        f = fopen(in_filename, "r");
+        if (!f)
+            yasm__fatal( N_("Could not open input file") );
+    }
+    else
+        f = stdin;
+
     preproc_raw->preproc.module = &yasm_raw_LTX_preproc;
     preproc_raw->in = f;
     preproc_raw->cur_lm = lm;
@@ -75,21 +83,21 @@ raw_preproc_input(yasm_preproc *preproc, char *buf, size_t max_size)
     size_t n;
 
     if (preproc_raw->is_interactive) {
-	for (n = 0; n < max_size && (c = getc(preproc_raw->in)) != EOF &&
-	     c != '\n'; n++)
-	    buf[n] = (char)c;
-	if (c == '\n')
-	    buf[n++] = (char)c;
-	if (c == EOF && ferror(preproc_raw->in)) {
-	    yasm_error_set(YASM_ERROR_IO, N_("error when reading from file"));
-	    yasm_errwarn_propagate(preproc_raw->errwarns,
-				   yasm_linemap_get_current(preproc_raw->cur_lm));
-	}
+        for (n = 0; n < max_size && (c = getc(preproc_raw->in)) != EOF &&
+             c != '\n'; n++)
+            buf[n] = (char)c;
+        if (c == '\n')
+            buf[n++] = (char)c;
+        if (c == EOF && ferror(preproc_raw->in)) {
+            yasm_error_set(YASM_ERROR_IO, N_("error when reading from file"));
+            yasm_errwarn_propagate(preproc_raw->errwarns,
+                                   yasm_linemap_get_current(preproc_raw->cur_lm));
+        }
     } else if (((n = fread(buf, 1, max_size, preproc_raw->in)) == 0) &&
-	       ferror(preproc_raw->in)) {
-	yasm_error_set(YASM_ERROR_IO, N_("error when reading from file"));
-	yasm_errwarn_propagate(preproc_raw->errwarns,
-			       yasm_linemap_get_current(preproc_raw->cur_lm));
+               ferror(preproc_raw->in)) {
+        yasm_error_set(YASM_ERROR_IO, N_("error when reading from file"));
+        yasm_errwarn_propagate(preproc_raw->errwarns,
+                               yasm_linemap_get_current(preproc_raw->cur_lm));
     }
 
     return n;
@@ -97,7 +105,7 @@ raw_preproc_input(yasm_preproc *preproc, char *buf, size_t max_size)
 
 static size_t
 raw_preproc_get_included_file(yasm_preproc *preproc, char *buf,
-			      size_t max_size)
+                              size_t max_size)
 {
     /* no included files */
     return 0;
